@@ -35,7 +35,7 @@ from time import time
 import numpy as np
 from matplotlib import pyplot as plt
 
-from sklearn import manifold, datasets
+from sklearn import datasets, manifold
 
 digits = datasets.load_digits()
 X, y = digits.data, digits.target
