@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 =========================================================
 Pipelining: chaining a PCA and a logistic regression
@@ -15,15 +14,15 @@ We use a GridSearchCV to set the dimensionality of the PCA
 # Modified for documentation by Jaques Grobler
 # License: BSD 3 clause
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 import pandas as pd
 
 from sklearn import datasets
 from sklearn.decomposition import PCA
 from sklearn.linear_model import LogisticRegression
-from sklearn.pipeline import Pipeline
 from sklearn.model_selection import GridSearchCV
+from sklearn.pipeline import Pipeline
 from sklearn.preprocessing import StandardScaler
 
 # Define a pipeline to search for the best combination of PCA truncation
@@ -66,12 +65,13 @@ ax0.legend(prop=dict(size=12))
 # For each number of components, find the best classifier results
 results = pd.DataFrame(search.cv_results_)
 components_col = "param_pca__n_components"
-best_clfs = results.groupby(components_col).apply(
-    lambda g: g.nlargest(1, "mean_test_score")
-)
-
-best_clfs.plot(
-    x=components_col, y="mean_test_score", yerr="std_test_score", legend=False, ax=ax1
+best_clfs = results.groupby(components_col)[
+    [components_col, "mean_test_score", "std_test_score"]
+].apply(lambda g: g.nlargest(1, "mean_test_score"))
+ax1.errorbar(
+    best_clfs[components_col],
+    best_clfs["mean_test_score"],
+    yerr=best_clfs["std_test_score"],
 )
 ax1.set_ylabel("Classification accuracy (val)")
 ax1.set_xlabel("n_components")
