@@ -12,7 +12,7 @@ This exercise is used in the :ref:`clf_tut` part of the
 
 """
 
-from sklearn import datasets, neighbors, linear_model
+from sklearn import datasets, linear_model, neighbors
 
 X_digits, y_digits = datasets.load_digits(return_X_y=True)
 X_digits = X_digits / X_digits.max()
