@@ -16,7 +16,12 @@ below what can be reached by an l2-penalized linear model or a non-linear
 multi-layer perceptron model on this dataset.
 
 """
+
+# Author: Arthur Mensch <arthur.mensch@m4x.org>
+# License: BSD 3 clause
+
 import time
+
 import matplotlib.pyplot as plt
 import numpy as np
 
@@ -26,17 +31,12 @@ from sklearn.model_selection import train_test_split
 from sklearn.preprocessing import StandardScaler
 from sklearn.utils import check_random_state
 
-print(__doc__)
-
-# Author: Arthur Mensch <arthur.mensch@m4x.org>
-# License: BSD 3 clause
-
 # Turn down for faster convergence
 t0 = time.time()
 train_samples = 5000
 
 # Load data from https://www.openml.org/d/554
-X, y = fetch_openml('mnist_784', version=1, return_X_y=True)
+X, y = fetch_openml("mnist_784", version=1, return_X_y=True, as_frame=False)
 
 random_state = check_random_state(0)
 permutation = random_state.permutation(X.shape[0])
@@ -45,16 +45,15 @@ y = y[permutation]
 X = X.reshape((X.shape[0], -1))
 
 X_train, X_test, y_train, y_test = train_test_split(
-    X, y, train_size=train_samples, test_size=10000)
+    X, y, train_size=train_samples, test_size=10000
+)
 
 scaler = StandardScaler()
 X_train = scaler.fit_transform(X_train)
 X_test = scaler.transform(X_test)
 
 # Turn up tolerance for faster convergence
-clf = LogisticRegression(
-    C=50. / train_samples, penalty='l1', solver='saga', tol=0.1
-)
+clf = LogisticRegression(C=50.0 / train_samples, penalty="l1", solver="saga", tol=0.1)
 clf.fit(X_train, y_train)
 sparsity = np.mean(clf.coef_ == 0) * 100
 score = clf.score(X_test, y_test)
@@ -67,13 +66,18 @@ plt.figure(figsize=(10, 5))
 scale = np.abs(coef).max()
 for i in range(10):
     l1_plot = plt.subplot(2, 5, i + 1)
-    l1_plot.imshow(coef[i].reshape(28, 28), interpolation='nearest',
-                   cmap=plt.cm.RdBu, vmin=-scale, vmax=scale)
+    l1_plot.imshow(
+        coef[i].reshape(28, 28),
+        interpolation="nearest",
+        cmap=plt.cm.RdBu,
+        vmin=-scale,
+        vmax=scale,
+    )
     l1_plot.set_xticks(())
     l1_plot.set_yticks(())
-    l1_plot.set_xlabel('Class %i' % i)
-plt.suptitle('Classification vector for...')
+    l1_plot.set_xlabel("Class %i" % i)
+plt.suptitle("Classification vector for...")
 
 run_time = time.time() - t0
-print('Example run in %.3f s' % run_time)
+print("Example run in %.3f s" % run_time)
 plt.show()
