@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 =============================================
 Manifold Learning methods on a severed sphere
@@ -30,15 +29,16 @@ that of representing a flat map of the Earth, as with
 # License: BSD 3 clause
 
 from time import time
-import numpy as np
+
 import matplotlib.pyplot as plt
-from matplotlib.ticker import NullFormatter
-from sklearn import manifold
-from sklearn.utils import check_random_state
 
 # Unused but required import for doing 3d projections with matplotlib < 3.2
 import mpl_toolkits.mplot3d  # noqa: F401
-import warnings
+import numpy as np
+from matplotlib.ticker import NullFormatter
+
+from sklearn import manifold
+from sklearn.utils import check_random_state
 
 # Variables for manifold learning.
 n_neighbors = 10
@@ -78,7 +78,7 @@ for i, method in enumerate(methods):
     t0 = time()
     trans_data = (
         manifold.LocallyLinearEmbedding(
-            n_neighbors=n_neighbors, n_components=2, method=method
+            n_neighbors=n_neighbors, n_components=2, method=method, random_state=42
         )
         .fit_transform(sphere_data)
         .T
@@ -112,7 +112,7 @@ plt.axis("tight")
 
 # Perform Multi-dimensional scaling.
 t0 = time()
-mds = manifold.MDS(2, max_iter=100, n_init=1)
+mds = manifold.MDS(2, max_iter=100, n_init=1, random_state=42)
 trans_data = mds.fit_transform(sphere_data).T
 t1 = time()
 print("MDS: %.2g sec" % (t1 - t0))
@@ -126,7 +126,9 @@ plt.axis("tight")
 
 # Perform Spectral Embedding.
 t0 = time()
-se = manifold.SpectralEmbedding(n_components=2, n_neighbors=n_neighbors)
+se = manifold.SpectralEmbedding(
+    n_components=2, n_neighbors=n_neighbors, random_state=42
+)
 trans_data = se.fit_transform(sphere_data).T
 t1 = time()
 print("Spectral Embedding: %.2g sec" % (t1 - t0))
@@ -139,17 +141,10 @@ ax.yaxis.set_major_formatter(NullFormatter())
 plt.axis("tight")
 
 # Perform t-distributed stochastic neighbor embedding.
-# TODO(1.2) Remove warning handling.
-with warnings.catch_warnings():
-    warnings.filterwarnings(
-        "ignore", message="The PCA initialization", category=FutureWarning
-    )
-    t0 = time()
-    tsne = manifold.TSNE(
-        n_components=2, init="pca", random_state=0, learning_rate="auto"
-    )
-    trans_data = tsne.fit_transform(sphere_data).T
-    t1 = time()
+t0 = time()
+tsne = manifold.TSNE(n_components=2, random_state=0)
+trans_data = tsne.fit_transform(sphere_data).T
+t1 = time()
 print("t-SNE: %.2g sec" % (t1 - t0))
 
 ax = fig.add_subplot(2, 5, 10)
