@@ -19,7 +19,7 @@ geospatial coordinates.
 The two species are:
 
  - `"Bradypus variegatus"
-   <http://www.iucnredlist.org/apps/redlist/details/3038/0>`_ ,
+   <https://www.iucnredlist.org/species/3038/47437046>`_ ,
    the Brown-throated Sloth.
 
  - `"Microryzomys minutus"
@@ -34,13 +34,15 @@ References
    <http://rob.schapire.net/papers/ecolmod.pdf>`_
    S. J. Phillips, R. P. Anderson, R. E. Schapire - Ecological Modelling,
    190:231-259, 2006.
-"""
+"""  # noqa: E501
+
 # Author: Jake Vanderplas <jakevdp@cs.washington.edu>
 #
 # License: BSD 3 clause
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
+
 from sklearn.datasets import fetch_species_distributions
 from sklearn.neighbors import KernelDensity
 
@@ -48,6 +50,7 @@ from sklearn.neighbors import KernelDensity
 # otherwise, we'll improvise later...
 try:
     from mpl_toolkits.basemap import Basemap
+
     basemap = True
 except ImportError:
     basemap = False
@@ -82,13 +85,14 @@ def construct_grids(batch):
 
 # Get matrices/arrays of species IDs and locations
 data = fetch_species_distributions()
-species_names = ['Bradypus Variegatus', 'Microryzomys Minutus']
+species_names = ["Bradypus Variegatus", "Microryzomys Minutus"]
 
-Xtrain = np.vstack([data['train']['dd lat'],
-                    data['train']['dd long']]).T
-ytrain = np.array([d.decode('ascii').startswith('micro')
-                  for d in data['train']['species']], dtype='int')
-Xtrain *= np.pi / 180.  # Convert lat/long to radians
+Xtrain = np.vstack([data["train"]["dd lat"], data["train"]["dd long"]]).T
+ytrain = np.array(
+    [d.decode("ascii").startswith("micro") for d in data["train"]["species"]],
+    dtype="int",
+)
+Xtrain *= np.pi / 180.0  # Convert lat/long to radians
 
 # Set up the data grid for the contour plot
 xgrid, ygrid = construct_grids(data)
@@ -98,7 +102,7 @@ land_mask = (land_reference > -9999).ravel()
 
 xy = np.vstack([Y.ravel(), X.ravel()]).T
 xy = xy[land_mask]
-xy *= np.pi / 180.
+xy *= np.pi / 180.0
 
 # Plot map of South America with distributions of each species
 fig = plt.figure()
@@ -109,12 +113,13 @@ for i in range(2):
 
     # construct a kernel density estimate of the distribution
     print(" - computing KDE in spherical coordinates")
-    kde = KernelDensity(bandwidth=0.04, metric='haversine',
-                        kernel='gaussian', algorithm='ball_tree')
+    kde = KernelDensity(
+        bandwidth=0.04, metric="haversine", kernel="gaussian", algorithm="ball_tree"
+    )
     kde.fit(Xtrain[ytrain == i])
 
     # evaluate only on the land: -9999 indicates ocean
-    Z = np.full(land_mask.shape[0], -9999, dtype='int')
+    Z = np.full(land_mask.shape[0], -9999, dtype="int")
     Z[land_mask] = np.exp(kde.score_samples(xy))
     Z = Z.reshape(X.shape)
 
@@ -124,16 +129,21 @@ for i in range(2):
 
     if basemap:
         print(" - plot coastlines using basemap")
-        m = Basemap(projection='cyl', llcrnrlat=Y.min(),
-                    urcrnrlat=Y.max(), llcrnrlon=X.min(),
-                    urcrnrlon=X.max(), resolution='c')
+        m = Basemap(
+            projection="cyl",
+            llcrnrlat=Y.min(),
+            urcrnrlat=Y.max(),
+            llcrnrlon=X.min(),
+            urcrnrlon=X.max(),
+            resolution="c",
+        )
         m.drawcoastlines()
         m.drawcountries()
     else:
         print(" - plot coastlines from coverage")
-        plt.contour(X, Y, land_reference,
-                    levels=[-9998], colors="k",
-                    linestyles="solid")
+        plt.contour(
+            X, Y, land_reference, levels=[-9998], colors="k", linestyles="solid"
+        )
         plt.xticks([])
         plt.yticks([])
 
