@@ -3,8 +3,10 @@
 Map data to a normal distribution
 =================================
 
+.. currentmodule:: sklearn.preprocessing
+
 This example demonstrates the use of the Box-Cox and Yeo-Johnson transforms
-through :class:`preprocessing.PowerTransformer` to map data from various
+through :class:`~PowerTransformer` to map data from various
 distributions to a normal distribution.
 
 The power transform is useful as a transformation in modeling problems where
@@ -22,28 +24,25 @@ lognormal and chi-squared distributions, keep in mind that Box-Cox does not
 support inputs with negative values.
 
 For comparison, we also add the output from
-:class:`preprocessing.QuantileTransformer`. It can force any arbitrary
+:class:`~QuantileTransformer`. It can force any arbitrary
 distribution into a gaussian, provided that there are enough training samples
 (thousands). Because it is a non-parametric method, it is harder to interpret
 than the parametric ones (Box-Cox and Yeo-Johnson).
 
 On "small" datasets (less than a few hundred points), the quantile transformer
 is prone to overfitting. The use of the power transform is then recommended.
+
 """
 
 # Author: Eric Chang <ericchang2017@u.northwestern.edu>
 #         Nicolas Hug <contact@nicolas-hug.com>
 # License: BSD 3 clause
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 
-from sklearn.preprocessing import PowerTransformer
-from sklearn.preprocessing import QuantileTransformer
 from sklearn.model_selection import train_test_split
-
-print(__doc__)
-
+from sklearn.preprocessing import PowerTransformer, QuantileTransformer
 
 N_SAMPLES = 1000
 FONT_SIZE = 6
@@ -51,9 +50,13 @@ BINS = 30
 
 
 rng = np.random.RandomState(304)
-bc = PowerTransformer(method='box-cox')
-yj = PowerTransformer(method='yeo-johnson')
-qt = QuantileTransformer(output_distribution='normal', random_state=rng)
+bc = PowerTransformer(method="box-cox")
+yj = PowerTransformer(method="yeo-johnson")
+# n_quantiles is set to the training set size rather than the default value
+# to avoid a warning being raised by this example
+qt = QuantileTransformer(
+    n_quantiles=500, output_distribution="normal", random_state=rng
+)
 size = (N_SAMPLES, 1)
 
 
@@ -83,28 +86,32 @@ X_bimodal = np.concatenate([X_a, X_b], axis=0)
 
 # create plots
 distributions = [
-    ('Lognormal', X_lognormal),
-    ('Chi-squared', X_chisq),
-    ('Weibull', X_weibull),
-    ('Gaussian', X_gaussian),
-    ('Uniform', X_uniform),
-    ('Bimodal', X_bimodal)
+    ("Lognormal", X_lognormal),
+    ("Chi-squared", X_chisq),
+    ("Weibull", X_weibull),
+    ("Gaussian", X_gaussian),
+    ("Uniform", X_uniform),
+    ("Bimodal", X_bimodal),
 ]
 
-colors = ['firebrick', 'darkorange', 'goldenrod',
-          'seagreen', 'royalblue', 'darkorchid']
+colors = ["#D81B60", "#0188FF", "#FFC107", "#B7A2FF", "#000000", "#2EC5AC"]
 
 fig, axes = plt.subplots(nrows=8, ncols=3, figsize=plt.figaspect(2))
 axes = axes.flatten()
-axes_idxs = [(0, 3, 6, 9), (1, 4, 7, 10), (2, 5, 8, 11), (12, 15, 18, 21),
-             (13, 16, 19, 22), (14, 17, 20, 23)]
-axes_list = [(axes[i], axes[j], axes[k], axes[l])
-             for (i, j, k, l) in axes_idxs]
+axes_idxs = [
+    (0, 3, 6, 9),
+    (1, 4, 7, 10),
+    (2, 5, 8, 11),
+    (12, 15, 18, 21),
+    (13, 16, 19, 22),
+    (14, 17, 20, 23),
+]
+axes_list = [(axes[i], axes[j], axes[k], axes[l]) for (i, j, k, l) in axes_idxs]
 
 
 for distribution, color, axes in zip(distributions, colors, axes_list):
     name, X = distribution
-    X_train, X_test = train_test_split(X, test_size=.5)
+    X_train, X_test = train_test_split(X, test_size=0.5)
 
     # perform power transforms and quantile transform
     X_trans_bc = bc.fit(X_train).transform(X_test)
@@ -117,19 +124,20 @@ for distribution, color, axes in zip(distributions, colors, axes_list):
 
     ax_original.hist(X_train, color=color, bins=BINS)
     ax_original.set_title(name, fontsize=FONT_SIZE)
-    ax_original.tick_params(axis='both', which='major', labelsize=FONT_SIZE)
+    ax_original.tick_params(axis="both", which="major", labelsize=FONT_SIZE)
 
     for ax, X_trans, meth_name, lmbda in zip(
-            (ax_bc, ax_yj, ax_qt),
-            (X_trans_bc, X_trans_yj, X_trans_qt),
-            ('Box-Cox', 'Yeo-Johnson', 'Quantile transform'),
-            (lmbda_bc, lmbda_yj, None)):
+        (ax_bc, ax_yj, ax_qt),
+        (X_trans_bc, X_trans_yj, X_trans_qt),
+        ("Box-Cox", "Yeo-Johnson", "Quantile transform"),
+        (lmbda_bc, lmbda_yj, None),
+    ):
         ax.hist(X_trans, color=color, bins=BINS)
-        title = 'After {}'.format(meth_name)
+        title = "After {}".format(meth_name)
         if lmbda is not None:
-            title += r'\n$\lambda$ = {}'.format(lmbda)
+            title += "\n$\\lambda$ = {}".format(lmbda)
         ax.set_title(title, fontsize=FONT_SIZE)
-        ax.tick_params(axis='both', which='major', labelsize=FONT_SIZE)
+        ax.tick_params(axis="both", which="major", labelsize=FONT_SIZE)
         ax.set_xlim([-3.5, 3.5])
 
 
