@@ -15,7 +15,7 @@ completely different model fit compared to the fit with unscaled data (such as
 KNeighbors models). The latter is demoed on the first part of the present
 example.
 
-On the second part of the example we show how Principle Component Analysis (PCA)
+On the second part of the example we show how Principal Component Analysis (PCA)
 is impacted by normalization of features. To illustrate this, we compare the
 principal components found using :class:`~sklearn.decomposition.PCA` on unscaled
 data with those obatined when using a
@@ -52,6 +52,8 @@ X_train, X_test, y_train, y_test = train_test_split(
 scaled_X_train = scaler.fit_transform(X_train)
 
 # %%
+# .. _neighbors_scaling:
+#
 # Effect of rescaling on a k-neighbors models
 # ===========================================
 #
@@ -65,10 +67,10 @@ scaled_X_train = scaler.fit_transform(X_train)
 # of features.
 
 import matplotlib.pyplot as plt
+
 from sklearn.inspection import DecisionBoundaryDisplay
 from sklearn.neighbors import KNeighborsClassifier
 
-
 X_plot = X[["proline", "hue"]]
 X_plot_scaled = scaler.fit_transform(X_plot)
 clf = KNeighborsClassifier(n_neighbors=20)
@@ -100,7 +102,7 @@ ax2.set_ylabel("scaled hue")
 _ = ax2.set_title("KNN with scaling")
 
 # %%
-# Here the desicion boundary shows that fitting scaled or non-scaled data lead
+# Here the decision boundary shows that fitting scaled or non-scaled data lead
 # to completely different models. The reason is that the variable "proline" has
 # values which vary between 0 and 1,000; whereas the variable "hue" varies
 # between 1 and 10. Because of this, distances between samples are mostly
@@ -122,6 +124,7 @@ _ = ax2.set_title("KNN with scaling")
 # We can inspect the first principal components using all the original features:
 
 import pandas as pd
+
 from sklearn.decomposition import PCA
 
 pca = PCA(n_components=2).fit(X_train)
@@ -187,7 +190,7 @@ _ = plt.tight_layout()
 # %%
 # From the plot above we observe that scaling the features before reducing the
 # dimensionality results in components with the same order of magnitude. In this
-# case it also improves the separability of the clases. Indeed, in the next
+# case it also improves the separability of the classes. Indeed, in the next
 # section we confirm that a better separability has a good repercussion on the
 # overall model's performance.
 #
@@ -199,8 +202,9 @@ _ = plt.tight_layout()
 # non-scaling of the data:
 
 import numpy as np
-from sklearn.pipeline import make_pipeline
+
 from sklearn.linear_model import LogisticRegressionCV
+from sklearn.pipeline import make_pipeline
 
 Cs = np.logspace(-5, 5, 20)
 
@@ -218,8 +222,7 @@ print(f"Optimal C for the standardized data with PCA: {scaled_clf[-1].C_[0]:.2f}
 # was not scaled before applying PCA. We now evaluate the effect of scaling on
 # the accuracy and the mean log-loss of the optimal models:
 
-from sklearn.metrics import accuracy_score
-from sklearn.metrics import log_loss
+from sklearn.metrics import accuracy_score, log_loss
 
 y_pred = unscaled_clf.predict(X_test)
 y_pred_scaled = scaled_clf.predict(X_test)
