@@ -9,18 +9,19 @@ vectors in LinearSVC.
 
 """
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
+
 from sklearn.datasets import make_blobs
-from sklearn.svm import LinearSVC
 from sklearn.inspection import DecisionBoundaryDisplay
+from sklearn.svm import LinearSVC
 
 X, y = make_blobs(n_samples=40, centers=2, random_state=0)
 
 plt.figure(figsize=(10, 5))
 for i, C in enumerate([1, 100]):
     # "hinge" is the standard SVM loss
-    clf = LinearSVC(C=C, loss="hinge", random_state=42).fit(X, y)
+    clf = LinearSVC(C=C, loss="hinge", random_state=42, dual="auto").fit(X, y)
     # obtain the support vectors through the decision function
     decision_function = clf.decision_function(X)
     # we can also calculate the decision function manually
