@@ -19,10 +19,10 @@ show how to retrieve:
 import numpy as np
 from matplotlib import pyplot as plt
 
-from sklearn.model_selection import train_test_split
-from sklearn.datasets import load_iris
-from sklearn.tree import DecisionTreeClassifier
 from sklearn import tree
+from sklearn.datasets import load_iris
+from sklearn.model_selection import train_test_split
+from sklearn.tree import DecisionTreeClassifier
 
 ##############################################################################
 # Train tree classifier
@@ -44,13 +44,15 @@ clf.fit(X_train, y_train)
 #
 # The decision classifier has an attribute called ``tree_`` which allows access
 # to low level attributes such as ``node_count``, the total number of nodes,
-# and ``max_depth``, the maximal depth of the tree. It also stores the
-# entire binary tree structure, represented as a number of parallel arrays. The
-# i-th element of each array holds information about the node ``i``. Node 0 is
-# the tree's root. Some of the arrays only apply to either leaves or split
-# nodes. In this case the values of the nodes of the other type is arbitrary.
-# For example, the arrays ``feature`` and ``threshold`` only apply to split
-# nodes. The values for leaf nodes in these arrays are therefore arbitrary.
+# and ``max_depth``, the maximal depth of the tree. The
+# ``tree_.compute_node_depths()`` method computes the depth of each node in the
+# tree. `tree_` also stores the entire binary tree structure, represented as a
+# number of parallel arrays. The i-th element of each array holds information
+# about the node ``i``. Node 0 is the tree's root. Some of the arrays only
+# apply to either leaves or split nodes. In this case the values of the nodes
+# of the other type is arbitrary. For example, the arrays ``feature`` and
+# ``threshold`` only apply to split nodes. The values for leaf nodes in these
+# arrays are therefore arbitrary.
 #
 # Among these arrays, we have:
 #
@@ -63,6 +65,10 @@ clf.fit(X_train, y_train)
 #   - ``n_node_samples[i]``: the number of training samples reaching node
 #     ``i``
 #   - ``impurity[i]``: the impurity at node ``i``
+#   - ``weighted_n_node_samples[i]``: the weighted number of training samples
+#     reaching node ``i``
+#   - ``value[i, j, k]``: the summary of the training samples that reached node i for
+#     class j and output k.
 #
 # Using the arrays, we can traverse the tree structure to compute various
 # properties. Below, we will compute the depth of each node and whether or not
@@ -73,6 +79,7 @@ children_left = clf.tree_.children_left
 children_right = clf.tree_.children_right
 feature = clf.tree_.feature
 threshold = clf.tree_.threshold
+values = clf.tree_.value
 
 node_depth = np.zeros(shape=n_nodes, dtype=np.int64)
 is_leaves = np.zeros(shape=n_nodes, dtype=bool)
@@ -100,13 +107,13 @@ print(
 for i in range(n_nodes):
     if is_leaves[i]:
         print(
-            "{space}node={node} is a leaf node.".format(
-                space=node_depth[i] * "\t", node=i
+            "{space}node={node} is a leaf node with value={value}.".format(
+                space=node_depth[i] * "\t", node=i, value=values[i]
             )
         )
     else:
         print(
-            "{space}node={node} is a split node: "
+            "{space}node={node} is a split node with value={value}: "
             "go to node {left} if X[:, {feature}] <= {threshold} "
             "else to node {right}.".format(
                 space=node_depth[i] * "\t",
@@ -115,9 +122,30 @@ for i in range(n_nodes):
                 feature=feature[i],
                 threshold=threshold[i],
                 right=children_right[i],
+                value=values[i],
             )
         )
 
+# %%
+# What is the values array used here?
+# -----------------------------------
+# The `tree_.value` array is a 3D array of shape
+# [``n_nodes``, ``n_classes``, ``n_outputs``] which provides the count of samples
+# reaching a node for each class and for each output. Each node has a ``value``
+# array which is the number of weighted samples reaching this
+# node for each output and class.
+#
+# For example, in the above tree built on the iris dataset, the root node has
+# ``value = [37, 34, 41]``, indicating there are 37 samples
+# of class 0, 34 samples of class 1, and 41 samples of class 2 at the root node.
+# Traversing the tree, the samples are split and as a result, the ``value`` array
+# reaching each node changes. The left child of the root node has ``value = [37, 0, 0]``
+# because all 37 samples in the left child node are from class 0.
+#
+# Note: In this example, `n_outputs=1`, but the tree classifier can also handle
+# multi-output problems. The `value` array at each node would just be a 2D
+# array instead.
+
 ##############################################################################
 # We can compare the above output to the plot of the decision tree.
 
