@@ -9,46 +9,58 @@
 
 import warnings
 from inspect import signature
-from functools import partial
-
 from math import log
+from numbers import Integral, Real
+
 import numpy as np
-from joblib import Parallel
-
+from scipy.optimize import minimize
 from scipy.special import expit
-from scipy.special import xlogy
-from scipy.optimize import fmin_bfgs
 
+from sklearn.utils import Bunch
+
+from ._loss import HalfBinomialLoss
 from .base import (
     BaseEstimator,
     ClassifierMixin,
-    RegressorMixin,
-    clone,
     MetaEstimatorMixin,
-    is_classifier,
+    RegressorMixin,
+    _fit_context,
+    clone,
 )
-from .preprocessing import label_binarize, LabelEncoder
+from .isotonic import IsotonicRegression
+from .model_selection import check_cv, cross_val_predict
+from .preprocessing import LabelEncoder, label_binarize
+from .svm import LinearSVC
 from .utils import (
+    _safe_indexing,
     column_or_1d,
     indexable,
-    check_matplotlib_support,
 )
-
+from .utils._param_validation import (
+    HasMethods,
+    Interval,
+    StrOptions,
+    validate_params,
+)
+from .utils._plotting import _BinaryClassifierCurveDisplayMixin
+from .utils._response import _get_response_values, _process_predict_proba
+from .utils.metadata_routing import (
+    MetadataRouter,
+    MethodMapping,
+    _routing_enabled,
+    process_routing,
+)
 from .utils.multiclass import check_classification_targets
-from .utils.fixes import delayed
+from .utils.parallel import Parallel, delayed
 from .utils.validation import (
-    _check_fit_params,
+    _check_method_params,
+    _check_pos_label_consistency,
+    _check_response_method,
     _check_sample_weight,
     _num_samples,
     check_consistent_length,
     check_is_fitted,
 )
-from .utils import _safe_indexing
-from .isotonic import IsotonicRegression
-from .svm import LinearSVC
-from .model_selection import check_cv, cross_val_predict
-from .metrics._base import _check_pos_label_consistency
-from .metrics._plot.base import _get_response
 
 
 class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator):
@@ -63,8 +75,9 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
     `ensemble=False`, cross-validation is used to obtain unbiased predictions,
     via :func:`~sklearn.model_selection.cross_val_predict`, which are then
     used for calibration. For prediction, the base estimator, trained using all
-    the data, is used. This is the method implemented when `probabilities=True`
-    for :mod:`sklearn.svm` estimators.
+    the data, is used. This is the prediction method implemented when
+    `probabilities=True` for :class:`~sklearn.svm.SVC` and :class:`~sklearn.svm.NuSVC`
+    estimators (see :ref:`User Guide <scores_probabilities>` for details).
 
     Already fitted classifiers can be calibrated via the parameter
     `cv="prefit"`. In this case, no cross-validation is used and all provided
@@ -72,17 +85,19 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
     for model fitting and calibration are disjoint.
 
     The calibration is based on the :term:`decision_function` method of the
-    `base_estimator` if it exists, else on :term:`predict_proba`.
+    `estimator` if it exists, else on :term:`predict_proba`.
 
     Read more in the :ref:`User Guide <calibration>`.
 
     Parameters
     ----------
-    base_estimator : estimator instance, default=None
+    estimator : estimator instance, default=None
         The classifier whose output need to be calibrated to provide more
         accurate `predict_proba` outputs. The default classifier is
         a :class:`~sklearn.svm.LinearSVC`.
 
+        .. versionadded:: 1.2
+
     method : {'sigmoid', 'isotonic'}, default='sigmoid'
         The method to use for calibration. Can be 'sigmoid' which
         corresponds to Platt's method (i.e. a logistic regression model) or
@@ -108,7 +123,7 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
         Refer to the :ref:`User Guide <cross_validation>` for the various
         cross-validation strategies that can be used here.
 
-        If "prefit" is passed, it is assumed that `base_estimator` has been
+        If "prefit" is passed, it is assumed that `estimator` has been
         fitted already and all data is used for calibration.
 
         .. versionchanged:: 0.22
@@ -130,7 +145,7 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
         Determines how the calibrator is fitted when `cv` is not `'prefit'`.
         Ignored if `cv='prefit'`.
 
-        If `True`, the `base_estimator` is fitted using training data, and
+        If `True`, the `estimator` is fitted using training data, and
         calibrated using testing data, for each `cv` fold. The final estimator
         is an ensemble of `n_cv` fitted classifier and calibrator pairs, where
         `n_cv` is the number of cross-validation folds. The output is the
@@ -139,7 +154,7 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
         If `False`, `cv` is used to compute unbiased predictions, via
         :func:`~sklearn.model_selection.cross_val_predict`, which are then
         used for calibration. At prediction time, the classifier used is the
-        `base_estimator` trained on all the data.
+        `estimator` trained on all the data.
         Note that this method is also internally implemented  in
         :mod:`sklearn.svm` estimators with the `probabilities=True` parameter.
 
@@ -152,13 +167,13 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
 
     n_features_in_ : int
         Number of features seen during :term:`fit`. Only defined if the
-        underlying base_estimator exposes such an attribute when fit.
+        underlying estimator exposes such an attribute when fit.
 
         .. versionadded:: 0.24
 
     feature_names_in_ : ndarray of shape (`n_features_in_`,)
         Names of features seen during :term:`fit`. Only defined if the
-        underlying base_estimator exposes such an attribute when fit.
+        underlying estimator exposes such an attribute when fit.
 
         .. versionadded:: 1.0
 
@@ -166,12 +181,12 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
             or `ensemble=False`)
         The list of classifier and calibrator pairs.
 
-        - When `cv="prefit"`, the fitted `base_estimator` and fitted
+        - When `cv="prefit"`, the fitted `estimator` and fitted
           calibrator.
         - When `cv` is not "prefit" and `ensemble=True`, `n_cv` fitted
-          `base_estimator` and calibrator pairs. `n_cv` is the number of
+          `estimator` and calibrator pairs. `n_cv` is the number of
           cross-validation folds.
-        - When `cv` is not "prefit" and `ensemble=False`, the `base_estimator`,
+        - When `cv` is not "prefit" and `ensemble=False`, the `estimator`,
           fitted on all the data, and fitted calibrator.
 
         .. versionchanged:: 0.24
@@ -204,9 +219,9 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
     >>> X, y = make_classification(n_samples=100, n_features=2,
     ...                            n_redundant=0, random_state=42)
     >>> base_clf = GaussianNB()
-    >>> calibrated_clf = CalibratedClassifierCV(base_estimator=base_clf, cv=3)
+    >>> calibrated_clf = CalibratedClassifierCV(base_clf, cv=3)
     >>> calibrated_clf.fit(X, y)
-    CalibratedClassifierCV(base_estimator=GaussianNB(), cv=3)
+    CalibratedClassifierCV(...)
     >>> len(calibrated_clf.calibrated_classifiers_)
     3
     >>> calibrated_clf.predict_proba(X)[:5, :]
@@ -224,33 +239,59 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
     >>> base_clf = GaussianNB()
     >>> base_clf.fit(X_train, y_train)
     GaussianNB()
-    >>> calibrated_clf = CalibratedClassifierCV(
-    ...     base_estimator=base_clf,
-    ...     cv="prefit"
-    ... )
+    >>> calibrated_clf = CalibratedClassifierCV(base_clf, cv="prefit")
     >>> calibrated_clf.fit(X_calib, y_calib)
-    CalibratedClassifierCV(base_estimator=GaussianNB(), cv='prefit')
+    CalibratedClassifierCV(...)
     >>> len(calibrated_clf.calibrated_classifiers_)
     1
     >>> calibrated_clf.predict_proba([[-0.5, 0.5]])
     array([[0.936..., 0.063...]])
     """
 
+    _parameter_constraints: dict = {
+        "estimator": [
+            HasMethods(["fit", "predict_proba"]),
+            HasMethods(["fit", "decision_function"]),
+            None,
+        ],
+        "method": [StrOptions({"isotonic", "sigmoid"})],
+        "cv": ["cv_object", StrOptions({"prefit"})],
+        "n_jobs": [Integral, None],
+        "ensemble": ["boolean"],
+    }
+
     def __init__(
         self,
-        base_estimator=None,
+        estimator=None,
         *,
         method="sigmoid",
         cv=None,
         n_jobs=None,
         ensemble=True,
     ):
-        self.base_estimator = base_estimator
+        self.estimator = estimator
         self.method = method
         self.cv = cv
         self.n_jobs = n_jobs
         self.ensemble = ensemble
 
+    def _get_estimator(self):
+        """Resolve which estimator to return (default is LinearSVC)"""
+        if self.estimator is None:
+            # we want all classifiers that don't expose a random_state
+            # to be deterministic (and we don't want to expose this one).
+            estimator = LinearSVC(random_state=0, dual="auto")
+            if _routing_enabled():
+                estimator.set_fit_request(sample_weight=True)
+        else:
+            estimator = self.estimator
+
+        return estimator
+
+    @_fit_context(
+        # CalibratedClassifierCV.estimator is not validated yet
+        prefer_skip_nested_validation=False
+    )
     def fit(self, X, y, sample_weight=None, **fit_params):
         """Fit the calibrated model.
 
@@ -279,28 +320,25 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
         if sample_weight is not None:
             sample_weight = _check_sample_weight(sample_weight, X)
 
-        for sample_aligned_params in fit_params.values():
-            check_consistent_length(y, sample_aligned_params)
-
-        if self.base_estimator is None:
-            # we want all classifiers that don't expose a random_state
-            # to be deterministic (and we don't want to expose this one).
-            base_estimator = LinearSVC(random_state=0)
-        else:
-            base_estimator = self.base_estimator
+        estimator = self._get_estimator()
 
         self.calibrated_classifiers_ = []
         if self.cv == "prefit":
-            # `classes_` should be consistent with that of base_estimator
-            check_is_fitted(self.base_estimator, attributes=["classes_"])
-            self.classes_ = self.base_estimator.classes_
+            # `classes_` should be consistent with that of estimator
+            check_is_fitted(self.estimator, attributes=["classes_"])
+            self.classes_ = self.estimator.classes_
 
-            pred_method, method_name = _get_prediction_method(base_estimator)
-            n_classes = len(self.classes_)
-            predictions = _compute_predictions(pred_method, method_name, X, n_classes)
+            predictions, _ = _get_response_values(
+                estimator,
+                X,
+                response_method=["decision_function", "predict_proba"],
+            )
+            if predictions.ndim == 1:
+                # Reshape binary output from `(n_samples,)` to `(n_samples, 1)`
+                predictions = predictions.reshape(-1, 1)
 
             calibrated_classifier = _fit_calibrator(
-                base_estimator,
+                estimator,
                 predictions,
                 y,
                 self.classes_,
@@ -312,22 +350,35 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
             # Set `classes_` using all `y`
             label_encoder_ = LabelEncoder().fit(y)
             self.classes_ = label_encoder_.classes_
-            n_classes = len(self.classes_)
 
-            # sample_weight checks
-            fit_parameters = signature(base_estimator.fit).parameters
-            supports_sw = "sample_weight" in fit_parameters
-            if sample_weight is not None and not supports_sw:
-                estimator_name = type(base_estimator).__name__
-                warnings.warn(
-                    f"Since {estimator_name} does not appear to accept sample_weight, "
-                    "sample weights will only be used for the calibration itself. This "
-                    "can be caused by a limitation of the current scikit-learn API. "
-                    "See the following issue for more details: "
-                    "https://github.com/scikit-learn/scikit-learn/issues/21134. Be "
-                    "warned that the result of the calibration is likely to be "
-                    "incorrect."
+            if _routing_enabled():
+                routed_params = process_routing(
+                    self,
+                    "fit",
+                    sample_weight=sample_weight,
+                    **fit_params,
                 )
+            else:
+                # sample_weight checks
+                fit_parameters = signature(estimator.fit).parameters
+                supports_sw = "sample_weight" in fit_parameters
+                if sample_weight is not None and not supports_sw:
+                    estimator_name = type(estimator).__name__
+                    warnings.warn(
+                        f"Since {estimator_name} does not appear to accept"
+                        " sample_weight, sample weights will only be used for the"
+                        " calibration itself. This can be caused by a limitation of"
+                        " the current scikit-learn API. See the following issue for"
+                        " more details:"
+                        " https://github.com/scikit-learn/scikit-learn/issues/21134."
+                        " Be warned that the result of the calibration is likely to be"
+                        " incorrect."
+                    )
+                routed_params = Bunch()
+                routed_params.splitter = Bunch(split={})  # no routing for splitter
+                routed_params.estimator = Bunch(fit=fit_params)
+                if sample_weight is not None and supports_sw:
+                    routed_params.estimator.fit["sample_weight"] = sample_weight
 
             # Check that each cross-validation fold can have at least one
             # example per class
@@ -351,45 +402,46 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
                 parallel = Parallel(n_jobs=self.n_jobs)
                 self.calibrated_classifiers_ = parallel(
                     delayed(_fit_classifier_calibrator_pair)(
-                        clone(base_estimator),
+                        clone(estimator),
                         X,
                         y,
                         train=train,
                         test=test,
                         method=self.method,
                         classes=self.classes_,
-                        supports_sw=supports_sw,
                         sample_weight=sample_weight,
-                        **fit_params,
+                        fit_params=routed_params.estimator.fit,
                     )
-                    for train, test in cv.split(X, y)
+                    for train, test in cv.split(X, y, **routed_params.splitter.split)
                 )
             else:
-                this_estimator = clone(base_estimator)
-                _, method_name = _get_prediction_method(this_estimator)
-                fit_params = (
-                    {"sample_weight": sample_weight}
-                    if sample_weight is not None and supports_sw
-                    else None
-                )
-                pred_method = partial(
-                    cross_val_predict,
+                this_estimator = clone(estimator)
+                method_name = _check_response_method(
+                    this_estimator,
+                    ["decision_function", "predict_proba"],
+                ).__name__
+                predictions = cross_val_predict(
                     estimator=this_estimator,
                     X=X,
                     y=y,
                     cv=cv,
                     method=method_name,
                     n_jobs=self.n_jobs,
-                    fit_params=fit_params,
-                )
-                predictions = _compute_predictions(
-                    pred_method, method_name, X, n_classes
+                    params=routed_params.estimator.fit,
                 )
+                if len(self.classes_) == 2:
+                    # Ensure shape (n_samples, 1) in the binary case
+                    if method_name == "predict_proba":
+                        # Select the probability column of the postive class
+                        predictions = _process_predict_proba(
+                            y_pred=predictions,
+                            target_type="binary",
+                            classes=self.classes_,
+                            pos_label=self.classes_[1],
+                        )
+                    predictions = predictions.reshape(-1, 1)
 
-                if sample_weight is not None and supports_sw:
-                    this_estimator.fit(X, y, sample_weight=sample_weight)
-                else:
-                    this_estimator.fit(X, y)
+                this_estimator.fit(X, y, **routed_params.estimator.fit)
                 # Note: Here we don't pass on fit_params because the supported
                 # calibrators don't support fit_params anyway
                 calibrated_classifier = _fit_calibrator(
@@ -402,7 +454,7 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
                 )
                 self.calibrated_classifiers_.append(calibrated_classifier)
 
-        first_clf = self.calibrated_classifiers_[0].base_estimator
+        first_clf = self.calibrated_classifiers_[0].estimator
         if hasattr(first_clf, "n_features_in_"):
             self.n_features_in_ = first_clf.n_features_in_
         if hasattr(first_clf, "feature_names_in_"):
@@ -418,7 +470,7 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
         Parameters
         ----------
         X : array-like of shape (n_samples, n_features)
-            The samples, as accepted by `base_estimator.predict_proba`.
+            The samples, as accepted by `estimator.predict_proba`.
 
         Returns
         -------
@@ -446,7 +498,7 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
         Parameters
         ----------
         X : array-like of shape (n_samples, n_features)
-            The samples, as accepted by `base_estimator.predict`.
+            The samples, as accepted by `estimator.predict`.
 
         Returns
         -------
@@ -456,6 +508,32 @@ class CalibratedClassifierCV(ClassifierMixin, MetaEstimatorMixin, BaseEstimator)
         check_is_fitted(self)
         return self.classes_[np.argmax(self.predict_proba(X), axis=1)]
 
+    def get_metadata_routing(self):
+        """Get metadata routing of this object.
+
+        Please check :ref:`User Guide <metadata_routing>` on how the routing
+        mechanism works.
+
+        Returns
+        -------
+        routing : MetadataRouter
+            A :class:`~sklearn.utils.metadata_routing.MetadataRouter` encapsulating
+            routing information.
+        """
+        router = (
+            MetadataRouter(owner=self.__class__.__name__)
+            .add_self_request(self)
+            .add(
+                estimator=self._get_estimator(),
+                method_mapping=MethodMapping().add(callee="fit", caller="fit"),
+            )
+            .add(
+                splitter=self.cv,
+                method_mapping=MethodMapping().add(callee="split", caller="fit"),
+            )
+        )
+        return router
+
     def _more_tags(self):
         return {
             "_xfail_checks": {
@@ -474,11 +552,10 @@ def _fit_classifier_calibrator_pair(
     y,
     train,
     test,
-    supports_sw,
     method,
     classes,
     sample_weight=None,
-    **fit_params,
+    fit_params=None,
 ):
     """Fit a classifier/calibration pair on a given train/test split.
 
@@ -503,9 +580,6 @@ def _fit_classifier_calibrator_pair(
     test : ndarray, shape (n_test_indices,)
         Indices of the testing subset.
 
-    supports_sw : bool
-        Whether or not the `estimator` supports sample weights.
-
     method : {'sigmoid', 'isotonic'}
         Method to use for calibration.
 
@@ -515,7 +589,7 @@ def _fit_classifier_calibrator_pair(
     sample_weight : array-like, default=None
         Sample weights for `X`.
 
-    **fit_params : dict
+    fit_params : dict, default=None
         Parameters to pass to the `fit` method of the underlying
         classifier.
 
@@ -523,19 +597,20 @@ def _fit_classifier_calibrator_pair(
     -------
     calibrated_classifier : _CalibratedClassifier instance
     """
-    fit_params_train = _check_fit_params(X, fit_params, train)
+    fit_params_train = _check_method_params(X, params=fit_params, indices=train)
     X_train, y_train = _safe_indexing(X, train), _safe_indexing(y, train)
     X_test, y_test = _safe_indexing(X, test), _safe_indexing(y, test)
 
-    if sample_weight is not None and supports_sw:
-        sw_train = _safe_indexing(sample_weight, train)
-        estimator.fit(X_train, y_train, sample_weight=sw_train, **fit_params_train)
-    else:
-        estimator.fit(X_train, y_train, **fit_params_train)
+    estimator.fit(X_train, y_train, **fit_params_train)
 
-    n_classes = len(classes)
-    pred_method, method_name = _get_prediction_method(estimator)
-    predictions = _compute_predictions(pred_method, method_name, X_test, n_classes)
+    predictions, _ = _get_response_values(
+        estimator,
+        X_test,
+        response_method=["decision_function", "predict_proba"],
+    )
+    if predictions.ndim == 1:
+        # Reshape binary output from `(n_samples,)` to `(n_samples, 1)`
+        predictions = predictions.reshape(-1, 1)
 
     sw_test = None if sample_weight is None else _safe_indexing(sample_weight, test)
     calibrated_classifier = _fit_calibrator(
@@ -544,74 +619,6 @@ def _fit_classifier_calibrator_pair(
     return calibrated_classifier
 
 
-def _get_prediction_method(clf):
-    """Return prediction method.
-
-    `decision_function` method of `clf` returned, if it
-    exists, otherwise `predict_proba` method returned.
-
-    Parameters
-    ----------
-    clf : Estimator instance
-        Fitted classifier to obtain the prediction method from.
-
-    Returns
-    -------
-    prediction_method : callable
-        The prediction method.
-    method_name : str
-        The name of the prediction method.
-    """
-    if hasattr(clf, "decision_function"):
-        method = getattr(clf, "decision_function")
-        return method, "decision_function"
-    elif hasattr(clf, "predict_proba"):
-        method = getattr(clf, "predict_proba")
-        return method, "predict_proba"
-    else:
-        raise RuntimeError(
-            "'base_estimator' has no 'decision_function' or 'predict_proba' method."
-        )
-
-
-def _compute_predictions(pred_method, method_name, X, n_classes):
-    """Return predictions for `X` and reshape binary outputs to shape
-    (n_samples, 1).
-
-    Parameters
-    ----------
-    pred_method : callable
-        Prediction method.
-
-    method_name: str
-        Name of the prediction method
-
-    X : array-like or None
-        Data used to obtain predictions.
-
-    n_classes : int
-        Number of classes present.
-
-    Returns
-    -------
-    predictions : array-like, shape (X.shape[0], len(clf.classes_))
-        The predictions. Note if there are 2 classes, array is of shape
-        (X.shape[0], 1).
-    """
-    predictions = pred_method(X=X)
-
-    if method_name == "decision_function":
-        if predictions.ndim == 1:
-            predictions = predictions[:, np.newaxis]
-    elif method_name == "predict_proba":
-        if n_classes == 2:
-            predictions = predictions[:, 1:]
-    else:  # pragma: no cover
-        # this branch should be unreachable.
-        raise ValueError(f"Invalid prediction method: {method_name}")
-    return predictions
-
-
 def _fit_calibrator(clf, predictions, y, classes, method, sample_weight=None):
     """Fit calibrator(s) and return a `_CalibratedClassifier`
     instance.
@@ -651,12 +658,8 @@ def _fit_calibrator(clf, predictions, y, classes, method, sample_weight=None):
     for class_idx, this_pred in zip(pos_class_indices, predictions.T):
         if method == "isotonic":
             calibrator = IsotonicRegression(out_of_bounds="clip")
-        elif method == "sigmoid":
+        else:  # "sigmoid"
             calibrator = _SigmoidCalibration()
-        else:
-            raise ValueError(
-                f"'method' should be one of: 'sigmoid' or 'isotonic'. Got {method}."
-            )
         calibrator.fit(this_pred, Y[:, class_idx], sample_weight)
         calibrators.append(calibrator)
 
@@ -669,7 +672,7 @@ class _CalibratedClassifier:
 
     Parameters
     ----------
-    base_estimator : estimator instance
+    estimator : estimator instance
         Fitted classifier.
 
     calibrators : list of fitted estimator instances
@@ -687,8 +690,8 @@ class _CalibratedClassifier:
         non-parametric approach based on isotonic regression.
     """
 
-    def __init__(self, base_estimator, calibrators, *, classes, method="sigmoid"):
-        self.base_estimator = base_estimator
+    def __init__(self, estimator, calibrators, *, classes, method="sigmoid"):
+        self.estimator = estimator
         self.calibrators = calibrators
         self.classes = classes
         self.method = method
@@ -709,12 +712,19 @@ class _CalibratedClassifier:
         proba : array, shape (n_samples, n_classes)
             The predicted probabilities. Can be exact zeros.
         """
+        predictions, _ = _get_response_values(
+            self.estimator,
+            X,
+            response_method=["decision_function", "predict_proba"],
+        )
+        if predictions.ndim == 1:
+            # Reshape binary output from `(n_samples,)` to `(n_samples, 1)`
+            predictions = predictions.reshape(-1, 1)
+
         n_classes = len(self.classes)
-        pred_method, method_name = _get_prediction_method(self.base_estimator)
-        predictions = _compute_predictions(pred_method, method_name, X, n_classes)
 
         label_encoder = LabelEncoder().fit(self.classes)
-        pos_class_indices = label_encoder.transform(self.base_estimator.classes_)
+        pos_class_indices = label_encoder.transform(self.estimator.classes_)
 
         proba = np.zeros((_num_samples(X), n_classes))
         for class_idx, this_pred, calibrator in zip(
@@ -745,7 +755,11 @@ class _CalibratedClassifier:
         return proba
 
 
-def _sigmoid_calibration(predictions, y, sample_weight=None):
+# The max_abs_prediction_threshold was approximated using
+# logit(np.finfo(np.float64).eps) which is about -36
+def _sigmoid_calibration(
+    predictions, y, sample_weight=None, max_abs_prediction_threshold=30
+):
     """Probability Calibration with sigmoid method (Platt 2000)
 
     Parameters
@@ -776,6 +790,20 @@ def _sigmoid_calibration(predictions, y, sample_weight=None):
 
     F = predictions  # F follows Platt's notations
 
+    scale_constant = 1.0
+    max_prediction = np.max(np.abs(F))
+
+    # If the predictions have large values we scale them in order to bring
+    # them within a suitable range. This has no effect on the final
+    # (prediction) result because linear models like Logisitic Regression
+    # without a penalty are invariant to multiplying the features by a
+    # constant.
+    if max_prediction >= max_abs_prediction_threshold:
+        scale_constant = max_prediction
+        # We rescale the features in a copy: inplace rescaling could confuse
+        # the caller and make the code harder to reason about.
+        F = F / scale_constant
+
     # Bayesian priors (see Platt end of section 2.2):
     # It corresponds to the number of samples, taking into account the
     # `sample_weight`.
@@ -786,33 +814,49 @@ def _sigmoid_calibration(predictions, y, sample_weight=None):
     else:
         prior0 = float(np.sum(mask_negative_samples))
         prior1 = y.shape[0] - prior0
-    T = np.zeros_like(y, dtype=np.float64)
+    T = np.zeros_like(y, dtype=predictions.dtype)
     T[y > 0] = (prior1 + 1.0) / (prior1 + 2.0)
     T[y <= 0] = 1.0 / (prior0 + 2.0)
-    T1 = 1.0 - T
 
-    def objective(AB):
-        # From Platt (beginning of Section 2.2)
-        P = expit(-(AB[0] * F + AB[1]))
-        loss = -(xlogy(T, P) + xlogy(T1, 1.0 - P))
-        if sample_weight is not None:
-            return (sample_weight * loss).sum()
-        else:
-            return loss.sum()
+    bin_loss = HalfBinomialLoss()
 
-    def grad(AB):
-        # gradient of the objective function
-        P = expit(-(AB[0] * F + AB[1]))
-        TEP_minus_T1P = T - P
-        if sample_weight is not None:
-            TEP_minus_T1P *= sample_weight
-        dA = np.dot(TEP_minus_T1P, F)
-        dB = np.sum(TEP_minus_T1P)
-        return np.array([dA, dB])
+    def loss_grad(AB):
+        # .astype below is needed to ensure y_true and raw_prediction have the
+        # same dtype. With result = np.float64(0) * np.array([1, 2], dtype=np.float32)
+        # - in Numpy 2, result.dtype is float64
+        # - in Numpy<2, result.dtype is float32
+        raw_prediction = -(AB[0] * F + AB[1]).astype(dtype=predictions.dtype)
+        l, g = bin_loss.loss_gradient(
+            y_true=T,
+            raw_prediction=raw_prediction,
+            sample_weight=sample_weight,
+        )
+        loss = l.sum()
+        # TODO: Remove casting to np.float64 when minimum supported SciPy is 1.11.2
+        # With SciPy >= 1.11.2, the LBFGS implementation will cast to float64
+        # https://github.com/scipy/scipy/pull/18825.
+        # Here we cast to float64 to support SciPy < 1.11.2
+        grad = np.asarray([-g @ F, -g.sum()], dtype=np.float64)
+        return loss, grad
 
     AB0 = np.array([0.0, log((prior0 + 1.0) / (prior1 + 1.0))])
-    AB_ = fmin_bfgs(objective, AB0, fprime=grad, disp=False)
-    return AB_[0], AB_[1]
+
+    opt_result = minimize(
+        loss_grad,
+        AB0,
+        method="L-BFGS-B",
+        jac=True,
+        options={
+            "gtol": 1e-6,
+            "ftol": 64 * np.finfo(float).eps,
+        },
+    )
+    AB_ = opt_result.x
+
+    # The tuned multiplicative parameter is converted back to the original
+    # input feature scale. The offset parameter does not need rescaling since
+    # we did not rescale the outcome variable.
+    return AB_[0] / scale_constant, AB_[1]
 
 
 class _SigmoidCalibration(RegressorMixin, BaseEstimator):
@@ -870,12 +914,21 @@ class _SigmoidCalibration(RegressorMixin, BaseEstimator):
         return expit(-(self.a_ * T + self.b_))
 
 
+@validate_params(
+    {
+        "y_true": ["array-like"],
+        "y_prob": ["array-like"],
+        "pos_label": [Real, str, "boolean", None],
+        "n_bins": [Interval(Integral, 1, None, closed="left")],
+        "strategy": [StrOptions({"uniform", "quantile"})],
+    },
+    prefer_skip_nested_validation=True,
+)
 def calibration_curve(
     y_true,
     y_prob,
     *,
     pos_label=None,
-    normalize="deprecated",
     n_bins=5,
     strategy="uniform",
 ):
@@ -896,22 +949,11 @@ def calibration_curve(
     y_prob : array-like of shape (n_samples,)
         Probabilities of the positive class.
 
-    pos_label : int or str, default=None
+    pos_label : int, float, bool or str, default=None
         The label of the positive class.
 
         .. versionadded:: 1.1
 
-    normalize : bool, default="deprecated"
-        Whether y_prob needs to be normalized into the [0, 1] interval, i.e.
-        is not a proper probability. If True, the smallest value in y_prob
-        is linearly mapped onto 0 and the largest one onto 1.
-
-        .. deprecated:: 1.1
-            The normalize argument is deprecated in v1.1 and will be removed in v1.3.
-            Explicitly normalizing `y_prob` will reproduce this behavior, but it is
-            recommended that a proper probability is used (i.e. a classifier's
-            `predict_proba` positive class).
-
     n_bins : int, default=5
         Number of bins to discretize the [0, 1] interval. A bigger number
         requires more data. Bins with no samples (i.e. without
@@ -959,19 +1001,6 @@ def calibration_curve(
     check_consistent_length(y_true, y_prob)
     pos_label = _check_pos_label_consistency(pos_label, y_true)
 
-    # TODO(1.3): Remove normalize conditional block.
-    if normalize != "deprecated":
-        warnings.warn(
-            "The normalize argument is deprecated in v1.1 and will be removed in v1.3."
-            " Explicitly normalizing y_prob will reproduce this behavior, but it is"
-            " recommended that a proper probability is used (i.e. a classifier's"
-            " `predict_proba` positive class or `decision_function` output calibrated"
-            " with `CalibratedClassifierCV`).",
-            FutureWarning,
-        )
-        if normalize:  # Normalize predicted values into interval [0, 1]
-            y_prob = (y_prob - y_prob.min()) / (y_prob.max() - y_prob.min())
-
     if y_prob.min() < 0 or y_prob.max() > 1:
         raise ValueError("y_prob has values outside [0, 1].")
 
@@ -1006,7 +1035,7 @@ def calibration_curve(
     return prob_true, prob_pred
 
 
-class CalibrationDisplay:
+class CalibrationDisplay(_BinaryClassifierCurveDisplayMixin):
     """Calibration curve (also known as reliability diagram) visualization.
 
     It is recommended to use
@@ -1034,10 +1063,10 @@ class CalibrationDisplay:
     estimator_name : str, default=None
         Name of estimator. If None, the estimator name is not shown.
 
-    pos_label : str or int, default=None
+    pos_label : int, float, bool or str, default=None
         The positive class when computing the calibration curve.
-        By default, `estimators.classes_[1]` is considered as the
-        positive class.
+        By default, `pos_label` is set to `estimators.classes_[1]` when using
+        `from_estimator` and set to 1 when using `from_predictions`.
 
         .. versionadded:: 1.1
 
@@ -1117,37 +1146,30 @@ class CalibrationDisplay:
         display : :class:`~sklearn.calibration.CalibrationDisplay`
             Object that stores computed values.
         """
-        check_matplotlib_support("CalibrationDisplay.plot")
-        import matplotlib.pyplot as plt
+        self.ax_, self.figure_, name = self._validate_plot_params(ax=ax, name=name)
 
-        if ax is None:
-            fig, ax = plt.subplots()
-
-        name = self.estimator_name if name is None else name
         info_pos_label = (
             f"(Positive class: {self.pos_label})" if self.pos_label is not None else ""
         )
 
-        line_kwargs = {}
+        line_kwargs = {"marker": "s", "linestyle": "-"}
         if name is not None:
             line_kwargs["label"] = name
         line_kwargs.update(**kwargs)
 
         ref_line_label = "Perfectly calibrated"
-        existing_ref_line = ref_line_label in ax.get_legend_handles_labels()[1]
+        existing_ref_line = ref_line_label in self.ax_.get_legend_handles_labels()[1]
         if ref_line and not existing_ref_line:
-            ax.plot([0, 1], [0, 1], "k:", label=ref_line_label)
-        self.line_ = ax.plot(self.prob_pred, self.prob_true, "s-", **line_kwargs)[0]
+            self.ax_.plot([0, 1], [0, 1], "k:", label=ref_line_label)
+        self.line_ = self.ax_.plot(self.prob_pred, self.prob_true, **line_kwargs)[0]
 
         # We always have to show the legend for at least the reference line
-        ax.legend(loc="lower right")
+        self.ax_.legend(loc="lower right")
 
         xlabel = f"Mean predicted probability {info_pos_label}"
         ylabel = f"Fraction of positives {info_pos_label}"
-        ax.set(xlabel=xlabel, ylabel=ylabel)
+        self.ax_.set(xlabel=xlabel, ylabel=ylabel)
 
-        self.ax_ = ax
-        self.figure_ = ax.figure
         return self
 
     @classmethod
@@ -1205,7 +1227,7 @@ class CalibrationDisplay:
             - `'quantile'`: The bins have the same number of samples and depend
               on predicted probabilities.
 
-        pos_label : str or int, default=None
+        pos_label : int, float, bool or str, default=None
             The positive class when computing the calibration curve.
             By default, `estimators.classes_[1]` is considered as the
             positive class.
@@ -1253,17 +1275,15 @@ class CalibrationDisplay:
         >>> disp = CalibrationDisplay.from_estimator(clf, X_test, y_test)
         >>> plt.show()
         """
-        method_name = f"{cls.__name__}.from_estimator"
-        check_matplotlib_support(method_name)
-
-        if not is_classifier(estimator):
-            raise ValueError("'estimator' should be a fitted classifier.")
-
-        y_prob, pos_label = _get_response(
-            X, estimator, response_method="predict_proba", pos_label=pos_label
+        y_prob, pos_label, name = cls._validate_and_get_response_values(
+            estimator,
+            X,
+            y,
+            response_method="predict_proba",
+            pos_label=pos_label,
+            name=name,
         )
 
-        name = name if name is not None else estimator.__class__.__name__
         return cls.from_predictions(
             y,
             y_prob,
@@ -1325,10 +1345,9 @@ class CalibrationDisplay:
             - `'quantile'`: The bins have the same number of samples and depend
               on predicted probabilities.
 
-        pos_label : str or int, default=None
+        pos_label : int, float, bool or str, default=None
             The positive class when computing the calibration curve.
-            By default, `estimators.classes_[1]` is considered as the
-            positive class.
+            By default `pos_label` is set to 1.
 
             .. versionadded:: 1.1
 
@@ -1373,20 +1392,19 @@ class CalibrationDisplay:
         >>> disp = CalibrationDisplay.from_predictions(y_test, y_prob)
         >>> plt.show()
         """
-        method_name = f"{cls.__name__}.from_estimator"
-        check_matplotlib_support(method_name)
+        pos_label_validated, name = cls._validate_from_predictions_params(
+            y_true, y_prob, sample_weight=None, pos_label=pos_label, name=name
+        )
 
         prob_true, prob_pred = calibration_curve(
             y_true, y_prob, n_bins=n_bins, strategy=strategy, pos_label=pos_label
         )
-        name = "Classifier" if name is None else name
-        pos_label = _check_pos_label_consistency(pos_label, y_true)
 
         disp = cls(
             prob_true=prob_true,
             prob_pred=prob_pred,
             y_prob=y_prob,
             estimator_name=name,
-            pos_label=pos_label,
+            pos_label=pos_label_validated,
         )
         return disp.plot(ax=ax, ref_line=ref_line, **kwargs)
