@@ -14,32 +14,36 @@ Generalized Linear Models.
 #         Maria Telenczuk <https://github.com/maikia>
 # License: BSD 3 clause
 
-from abc import ABCMeta, abstractmethod
 import numbers
 import warnings
+from abc import ABCMeta, abstractmethod
+from numbers import Integral
 
 import numpy as np
 import scipy.sparse as sp
-from scipy import linalg
-from scipy import optimize
-from scipy import sparse
+from scipy import linalg, optimize, sparse
 from scipy.sparse.linalg import lsqr
 from scipy.special import expit
-from numbers import Integral
 
-from ..base import BaseEstimator, ClassifierMixin, RegressorMixin, MultiOutputMixin
-from ..preprocessing._data import _is_constant_feature
-from ..utils import check_array
-from ..utils.validation import FLOAT_DTYPES
-from ..utils import check_random_state
-from ..utils.extmath import safe_sparse_dot
-from ..utils.extmath import _incremental_mean_and_var
-from ..utils.sparsefuncs import mean_variance_axis, inplace_column_scale
+from ..base import (
+    BaseEstimator,
+    ClassifierMixin,
+    MultiOutputMixin,
+    RegressorMixin,
+    _fit_context,
+)
+from ..utils import check_array, check_random_state
 from ..utils._array_api import get_namespace
-from ..utils._seq_dataset import ArrayDataset32, CSRDataset32
-from ..utils._seq_dataset import ArrayDataset64, CSRDataset64
-from ..utils.validation import check_is_fitted, _check_sample_weight
-from ..utils.parallel import delayed, Parallel
+from ..utils._seq_dataset import (
+    ArrayDataset32,
+    ArrayDataset64,
+    CSRDataset32,
+    CSRDataset64,
+)
+from ..utils.extmath import safe_sparse_dot
+from ..utils.parallel import Parallel, delayed
+from ..utils.sparsefuncs import mean_variance_axis
+from ..utils.validation import FLOAT_DTYPES, _check_sample_weight, check_is_fitted
 
 # TODO: bayesian_ridge_regression and bayesian_regression_ard
 # should be squashed into its respective objects.
@@ -49,83 +53,6 @@ SPARSE_INTERCEPT_DECAY = 0.01
 # intercept oscillation.
 
 
-# TODO(1.4): remove
-# parameter 'normalize' should be removed from linear models
-def _deprecate_normalize(normalize, estimator_name):
-    """Normalize is to be deprecated from linear models and a use of
-    a pipeline with a StandardScaler is to be recommended instead.
-    Here the appropriate message is selected to be displayed to the user
-    depending on the default normalize value (as it varies between the linear
-    models and normalize value selected by the user).
-
-    Parameters
-    ----------
-    normalize : bool,
-        normalize value passed by the user
-
-    estimator_name : str
-        name of the linear estimator which calls this function.
-        The name will be used for writing the deprecation warnings
-
-    Returns
-    -------
-    normalize : bool,
-        normalize value which should further be used by the estimator at this
-        stage of the depreciation process
-
-    Notes
-    -----
-    This function should be completely removed in 1.4.
-    """
-
-    if normalize not in [True, False, "deprecated"]:
-        raise ValueError(
-            "Leave 'normalize' to its default value or set it to True or False"
-        )
-
-    if normalize == "deprecated":
-        _normalize = False
-    else:
-        _normalize = normalize
-
-    pipeline_msg = (
-        "If you wish to scale the data, use Pipeline with a StandardScaler "
-        "in a preprocessing stage. To reproduce the previous behavior:\n\n"
-        "from sklearn.pipeline import make_pipeline\n\n"
-        "model = make_pipeline(StandardScaler(with_mean=False), "
-        f"{estimator_name}())\n\n"
-        "If you wish to pass a sample_weight parameter, you need to pass it "
-        "as a fit parameter to each step of the pipeline as follows:\n\n"
-        "kwargs = {s[0] + '__sample_weight': sample_weight for s "
-        "in model.steps}\n"
-        "model.fit(X, y, **kwargs)\n\n"
-    )
-
-    alpha_msg = ""
-    if "LassoLars" in estimator_name:
-        alpha_msg = "Set parameter alpha to: original_alpha * np.sqrt(n_samples). "
-
-    if normalize != "deprecated" and normalize:
-        warnings.warn(
-            "'normalize' was deprecated in version 1.2 and will be removed in 1.4.\n"
-            + pipeline_msg
-            + alpha_msg,
-            FutureWarning,
-        )
-    elif not normalize:
-        warnings.warn(
-            "'normalize' was deprecated in version 1.2 and will be "
-            "removed in 1.4. "
-            "Please leave the normalize parameter to its default value to "
-            "silence this warning. The default behavior of this estimator "
-            "is to not do any normalization. If normalization is needed "
-            "please use sklearn.preprocessing.StandardScaler instead.",
-            FutureWarning,
-        )
-
-    return _normalize
-
-
 def make_dataset(X, y, sample_weight, random_state=None):
     """Create ``Dataset`` abstraction for sparse and dense inputs.
 
@@ -182,29 +109,35 @@ def make_dataset(X, y, sample_weight, random_state=None):
 def _preprocess_data(
     X,
     y,
+    *,
     fit_intercept,
-    normalize=False,
     copy=True,
+    copy_y=True,
     sample_weight=None,
     check_input=True,
 ):
-    """Center and scale data.
+    """Common data preprocessing for fitting linear models.
 
-    Centers data to have mean zero along axis 0. If fit_intercept=False or if
-    the X is a sparse matrix, no centering is done, but normalization can still
-    be applied. The function returns the statistics necessary to reconstruct
-    the input data, which are X_offset, y_offset, X_scale, such that the output
+    This helper is in charge of the following steps:
 
-        X = (X - X_offset) / X_scale
+    - Ensure that `sample_weight` is an array or `None`.
+    - If `check_input=True`, perform standard input validation of `X`, `y`.
+    - Perform copies if requested to avoid side-effects in case of inplace
+      modifications of the input.
 
-    X_scale is the L2 norm of X - X_offset. If sample_weight is not None,
-    then the weighted mean of X and y is zero, and not the mean itself. If
-    fit_intercept=True, the mean, eventually weighted, is returned, independently
-    of whether X was centered (option used for optimization with sparse data in
-    coordinate_descend).
+    Then, if `fit_intercept=True` this preprocessing centers both `X` and `y` as
+    follows:
+        - if `X` is dense, center the data and
+        store the mean vector in `X_offset`.
+        - if `X` is sparse, store the mean in `X_offset`
+        without centering `X`. The centering is expected to be handled by the
+        linear solver where appropriate.
+        - in either case, always center `y` and store the mean in `y_offset`.
+        - both `X_offset` and `y_offset` are always weighted by `sample_weight`
+          if not set to `None`.
 
-    This is here because nearly all linear models will want their data to be
-    centered. This function also systematically makes y consistent with X.dtype
+    If `fit_intercept=False`, no centering is performed and `X_offset`, `y_offset`
+    are set to zero.
 
     Returns
     -------
@@ -212,14 +145,15 @@ def _preprocess_data(
         If copy=True a copy of the input X is triggered, otherwise operations are
         inplace.
         If input X is dense, then X_out is centered.
-        If normalize is True, then X_out is rescaled (dense and sparse case)
     y_out : {ndarray, sparse matrix} of shape (n_samples,) or (n_samples, n_targets)
-        Centered version of y. Likely performed inplace on input y.
+        Centered version of y. Possibly performed inplace on input y depending
+        on the copy_y parameter.
     X_offset : ndarray of shape (n_features,)
         The mean per column of input X.
     y_offset : float or ndarray of shape (n_features,)
     X_scale : ndarray of shape (n_features,)
-        The standard deviation per column of input X.
+        Always an array of ones. TODO: refactor the code base to make it
+        possible to remove this unused variable.
     """
     if isinstance(sample_weight, numbers.Number):
         sample_weight = None
@@ -228,61 +162,36 @@ def _preprocess_data(
 
     if check_input:
         X = check_array(X, copy=copy, accept_sparse=["csr", "csc"], dtype=FLOAT_DTYPES)
-    elif copy:
-        if sp.issparse(X):
-            X = X.copy()
-        else:
-            X = X.copy(order="K")
-
-    y = np.asarray(y, dtype=X.dtype)
+        y = check_array(y, dtype=X.dtype, copy=copy_y, ensure_2d=False)
+    else:
+        y = y.astype(X.dtype, copy=copy_y)
+        if copy:
+            if sp.issparse(X):
+                X = X.copy()
+            else:
+                X = X.copy(order="K")
 
     if fit_intercept:
         if sp.issparse(X):
             X_offset, X_var = mean_variance_axis(X, axis=0, weights=sample_weight)
         else:
-            if normalize:
-                X_offset, X_var, _ = _incremental_mean_and_var(
-                    X,
-                    last_mean=0.0,
-                    last_variance=0.0,
-                    last_sample_count=0.0,
-                    sample_weight=sample_weight,
-                )
-            else:
-                X_offset = np.average(X, axis=0, weights=sample_weight)
+            X_offset = np.average(X, axis=0, weights=sample_weight)
 
             X_offset = X_offset.astype(X.dtype, copy=False)
             X -= X_offset
 
-        if normalize:
-            X_var = X_var.astype(X.dtype, copy=False)
-            # Detect constant features on the computed variance, before taking
-            # the np.sqrt. Otherwise constant features cannot be detected with
-            # sample weights.
-            constant_mask = _is_constant_feature(X_var, X_offset, X.shape[0])
-            if sample_weight is None:
-                X_var *= X.shape[0]
-            else:
-                X_var *= sample_weight.sum()
-            X_scale = np.sqrt(X_var, out=X_var)
-            X_scale[constant_mask] = 1.0
-            if sp.issparse(X):
-                inplace_column_scale(X, 1.0 / X_scale)
-            else:
-                X /= X_scale
-        else:
-            X_scale = np.ones(X.shape[1], dtype=X.dtype)
-
         y_offset = np.average(y, axis=0, weights=sample_weight)
-        y = y - y_offset
+        y -= y_offset
     else:
         X_offset = np.zeros(X.shape[1], dtype=X.dtype)
-        X_scale = np.ones(X.shape[1], dtype=X.dtype)
         if y.ndim == 1:
             y_offset = X.dtype.type(0)
         else:
             y_offset = np.zeros(y.shape[1], dtype=X.dtype)
 
+    # XXX: X_scale is no longer needed. It is an historic artifact from the
+    # time where linear model exposed the normalize parameter.
+    X_scale = np.ones(X.shape[1], dtype=X.dtype)
     return X, y, X_offset, y_offset, X_scale
 
 
@@ -291,7 +200,7 @@ def _preprocess_data(
 # sample_weight makes the refactoring tricky.
 
 
-def _rescale_data(X, y, sample_weight):
+def _rescale_data(X, y, sample_weight, inplace=False):
     """Rescale data sample-wise by square root of sample_weight.
 
     For many linear models, this enables easy support for sample_weight because
@@ -313,14 +222,37 @@ def _rescale_data(X, y, sample_weight):
 
     y_rescaled : {array-like, sparse matrix}
     """
+    # Assume that _validate_data and _check_sample_weight have been called by
+    # the caller.
     n_samples = X.shape[0]
-    sample_weight = np.asarray(sample_weight)
-    if sample_weight.ndim == 0:
-        sample_weight = np.full(n_samples, sample_weight, dtype=sample_weight.dtype)
     sample_weight_sqrt = np.sqrt(sample_weight)
-    sw_matrix = sparse.dia_matrix((sample_weight_sqrt, 0), shape=(n_samples, n_samples))
-    X = safe_sparse_dot(sw_matrix, X)
-    y = safe_sparse_dot(sw_matrix, y)
+
+    if sp.issparse(X) or sp.issparse(y):
+        sw_matrix = sparse.dia_matrix(
+            (sample_weight_sqrt, 0), shape=(n_samples, n_samples)
+        )
+
+    if sp.issparse(X):
+        X = safe_sparse_dot(sw_matrix, X)
+    else:
+        if inplace:
+            X *= sample_weight_sqrt[:, np.newaxis]
+        else:
+            X = X * sample_weight_sqrt[:, np.newaxis]
+
+    if sp.issparse(y):
+        y = safe_sparse_dot(sw_matrix, y)
+    else:
+        if inplace:
+            if y.ndim == 1:
+                y *= sample_weight_sqrt
+            else:
+                y *= sample_weight_sqrt[:, np.newaxis]
+        else:
+            if y.ndim == 1:
+                y = y * sample_weight_sqrt
+            else:
+                y = y * sample_weight_sqrt[:, np.newaxis]
     return X, y, sample_weight_sqrt
 
 
@@ -399,7 +331,7 @@ class LinearClassifierMixin(ClassifierMixin):
 
         X = self._validate_data(X, accept_sparse="csr", reset=False)
         scores = safe_sparse_dot(X, self.coef_.T, dense_output=True) + self.intercept_
-        return xp.reshape(scores, -1) if scores.shape[1] == 1 else scores
+        return xp.reshape(scores, (-1,)) if scores.shape[1] == 1 else scores
 
     def predict(self, X):
         """
@@ -615,6 +547,7 @@ class LinearRegression(MultiOutputMixin, RegressorMixin, LinearModel):
         self.n_jobs = n_jobs
         self.positive = positive
 
+    @_fit_context(prefer_skip_nested_validation=True)
     def fit(self, X, y, sample_weight=None):
         """
         Fit linear model.
@@ -638,9 +571,6 @@ class LinearRegression(MultiOutputMixin, RegressorMixin, LinearModel):
         self : object
             Fitted Estimator.
         """
-
-        self._validate_params()
-
         n_jobs_ = self.n_jobs
 
         accept_sparse = False if self.positive else ["csr", "csc", "coo"]
@@ -649,20 +579,32 @@ class LinearRegression(MultiOutputMixin, RegressorMixin, LinearModel):
             X, y, accept_sparse=accept_sparse, y_numeric=True, multi_output=True
         )
 
-        sample_weight = _check_sample_weight(
-            sample_weight, X, dtype=X.dtype, only_non_negative=True
-        )
+        has_sw = sample_weight is not None
+        if has_sw:
+            sample_weight = _check_sample_weight(
+                sample_weight, X, dtype=X.dtype, only_non_negative=True
+            )
+
+        # Note that neither _rescale_data nor the rest of the fit method of
+        # LinearRegression can benefit from in-place operations when X is a
+        # sparse matrix. Therefore, let's not copy X when it is sparse.
+        copy_X_in_preprocess_data = self.copy_X and not sp.issparse(X)
 
         X, y, X_offset, y_offset, X_scale = _preprocess_data(
             X,
             y,
             fit_intercept=self.fit_intercept,
-            copy=self.copy_X,
+            copy=copy_X_in_preprocess_data,
             sample_weight=sample_weight,
         )
 
-        # Sample weight can be implemented via a simple rescaling.
-        X, y, sample_weight_sqrt = _rescale_data(X, y, sample_weight)
+        if has_sw:
+            # Sample weight can be implemented via a simple rescaling. Note
+            # that we safely do inplace rescaling when _preprocess_data has
+            # already made a copy if requested.
+            X, y, sample_weight_sqrt = _rescale_data(
+                X, y, sample_weight, inplace=copy_X_in_preprocess_data
+            )
 
         if self.positive:
             if y.ndim < 2:
@@ -676,11 +618,21 @@ class LinearRegression(MultiOutputMixin, RegressorMixin, LinearModel):
         elif sp.issparse(X):
             X_offset_scale = X_offset / X_scale
 
-            def matvec(b):
-                return X.dot(b) - sample_weight_sqrt * b.dot(X_offset_scale)
+            if has_sw:
 
-            def rmatvec(b):
-                return X.T.dot(b) - X_offset_scale * b.dot(sample_weight_sqrt)
+                def matvec(b):
+                    return X.dot(b) - sample_weight_sqrt * b.dot(X_offset_scale)
+
+                def rmatvec(b):
+                    return X.T.dot(b) - X_offset_scale * b.dot(sample_weight_sqrt)
+
+            else:
+
+                def matvec(b):
+                    return X.dot(b) - b.dot(X_offset_scale)
+
+                def rmatvec(b):
+                    return X.T.dot(b) - X_offset_scale * b.sum()
 
             X_centered = sparse.linalg.LinearOperator(
                 shape=X.shape, matvec=matvec, rmatvec=rmatvec
@@ -774,7 +726,6 @@ def _pre_fit(
     y,
     Xy,
     precompute,
-    normalize,
     fit_intercept,
     copy,
     check_input=True,
@@ -787,14 +738,13 @@ def _pre_fit(
     """
     n_samples, n_features = X.shape
 
-    if sparse.isspmatrix(X):
+    if sparse.issparse(X):
         # copy is not needed here as X is not modified inplace when X is sparse
         precompute = False
         X, y, X_offset, y_offset, X_scale = _preprocess_data(
             X,
             y,
             fit_intercept=fit_intercept,
-            normalize=normalize,
             copy=False,
             check_input=check_input,
             sample_weight=sample_weight,
@@ -805,7 +755,6 @@ def _pre_fit(
             X,
             y,
             fit_intercept=fit_intercept,
-            normalize=normalize,
             copy=copy,
             check_input=check_input,
             sample_weight=sample_weight,
@@ -816,19 +765,18 @@ def _pre_fit(
             # This triggers copies anyway.
             X, y, _ = _rescale_data(X, y, sample_weight=sample_weight)
 
-    # FIXME: 'normalize' to be removed in 1.4
     if hasattr(precompute, "__array__"):
-        if (
-            fit_intercept
-            and not np.allclose(X_offset, np.zeros(n_features))
-            or normalize
-            and not np.allclose(X_scale, np.ones(n_features))
-        ):
+        if fit_intercept and not np.allclose(X_offset, np.zeros(n_features)):
             warnings.warn(
-                "Gram matrix was provided but X was centered to fit "
-                "intercept, or X was normalized : recomputing Gram matrix.",
+                (
+                    "Gram matrix was provided but X was centered to fit "
+                    "intercept: recomputing Gram matrix."
+                ),
                 UserWarning,
             )
+            # TODO: instead of warning and recomputing, we could just center
+            # the user provided Gram matrix a-posteriori (after making a copy
+            # when `copy=True`).
             # recompute Gram
             precompute = "auto"
             Xy = None
