@@ -2,9 +2,7 @@
 The :mod:`sklearn.mixture` module implements mixture modeling algorithms.
 """
 
-from ._gaussian_mixture import GaussianMixture
 from ._bayesian_mixture import BayesianGaussianMixture
+from ._gaussian_mixture import GaussianMixture
 
-
-__all__ = ['GaussianMixture',
-           'BayesianGaussianMixture']
+__all__ = ["GaussianMixture", "BayesianGaussianMixture"]
