@@ -2,39 +2,42 @@
 #         Thierry Guillemot <thierry.guillemot.work@gmail.com>
 # License: BSD 3 clause
 
+import copy
 import itertools
 import re
 import sys
-import copy
 import warnings
-import pytest
+from io import StringIO
+from unittest.mock import Mock
 
 import numpy as np
-from scipy import stats, linalg
+import pytest
+from scipy import linalg, stats
 
+import sklearn
 from sklearn.cluster import KMeans
 from sklearn.covariance import EmpiricalCovariance
 from sklearn.datasets import make_spd_matrix
-from io import StringIO
+from sklearn.exceptions import ConvergenceWarning, NotFittedError
 from sklearn.metrics.cluster import adjusted_rand_score
 from sklearn.mixture import GaussianMixture
 from sklearn.mixture._gaussian_mixture import (
-    _estimate_gaussian_covariances_full,
-    _estimate_gaussian_covariances_tied,
-    _estimate_gaussian_covariances_diag,
-    _estimate_gaussian_covariances_spherical,
-    _estimate_gaussian_parameters,
-    _compute_precision_cholesky,
     _compute_log_det_cholesky,
+    _compute_precision_cholesky,
+    _estimate_gaussian_covariances_diag,
+    _estimate_gaussian_covariances_full,
+    _estimate_gaussian_covariances_spherical,
+    _estimate_gaussian_covariances_tied,
+    _estimate_gaussian_parameters,
+)
+from sklearn.utils._testing import (
+    assert_allclose,
+    assert_almost_equal,
+    assert_array_almost_equal,
+    assert_array_equal,
+    ignore_warnings,
 )
-from sklearn.exceptions import ConvergenceWarning, NotFittedError
 from sklearn.utils.extmath import fast_logdet
-from sklearn.utils._testing import assert_allclose
-from sklearn.utils._testing import assert_almost_equal
-from sklearn.utils._testing import assert_array_almost_equal
-from sklearn.utils._testing import assert_array_equal
-from sklearn.utils._testing import ignore_warnings
-
 
 COVARIANCE_TYPE = ["full", "tied", "diag", "spherical"]
 
@@ -128,52 +131,6 @@ def test_gaussian_mixture_attributes():
     rng = np.random.RandomState(0)
     X = rng.rand(10, 2)
 
-    n_components_bad = 0
-    gmm = GaussianMixture(n_components=n_components_bad)
-    msg = f"n_components == {n_components_bad}, must be >= 1."
-    with pytest.raises(ValueError, match=msg):
-        gmm.fit(X)
-
-    # covariance_type should be in [spherical, diag, tied, full]
-    covariance_type_bad = "bad_covariance_type"
-    gmm = GaussianMixture(covariance_type=covariance_type_bad)
-    msg = re.escape(
-        f"Invalid value for 'covariance_type': {covariance_type_bad} 'covariance_type'"
-        + " should be in ['spherical', 'tied', 'diag', 'full']"
-    )
-    with pytest.raises(ValueError, match=msg):
-        gmm.fit(X)
-
-    tol_bad = -1
-    gmm = GaussianMixture(tol=tol_bad)
-    msg = f"tol == {tol_bad}, must be >= 0."
-    with pytest.raises(ValueError, match=msg):
-        gmm.fit(X)
-
-    reg_covar_bad = -1
-    gmm = GaussianMixture(reg_covar=reg_covar_bad)
-    msg = f"reg_covar == {reg_covar_bad}, must be >= 0."
-    with pytest.raises(ValueError, match=msg):
-        gmm.fit(X)
-
-    max_iter_bad = -1
-    gmm = GaussianMixture(max_iter=max_iter_bad)
-    msg = f"max_iter == {max_iter_bad}, must be >= 0."
-    with pytest.raises(ValueError, match=msg):
-        gmm.fit(X)
-
-    n_init_bad = 0
-    gmm = GaussianMixture(n_init=n_init_bad)
-    msg = f"n_init == {n_init_bad}, must be >= 1."
-    with pytest.raises(ValueError, match=msg):
-        gmm.fit(X)
-
-    init_params_bad = "bad_method"
-    gmm = GaussianMixture(init_params=init_params_bad)
-    msg = f"Unimplemented initialization method '{init_params_bad}'"
-    with pytest.raises(ValueError, match=msg):
-        gmm.fit(X)
-
     # test good parameters
     n_components, tol, n_init, max_iter, reg_covar = 2, 1e-4, 3, 30, 1e-1
     covariance_type, init_params = "full", "random"
@@ -1032,7 +989,7 @@ def test_monotonic_likelihood():
             random_state=rng,
             tol=1e-7,
         )
-        current_log_likelihood = -np.infty
+        current_log_likelihood = -np.inf
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", ConvergenceWarning)
             # Do one training iteration at a time so we can make sure that the
@@ -1096,7 +1053,6 @@ def test_property():
         gmm.fit(X)
         if covar_type == "full":
             for prec, covar in zip(gmm.precisions_, gmm.covariances_):
-
                 assert_array_almost_equal(linalg.inv(prec), covar)
         elif covar_type == "tied":
             assert_array_almost_equal(linalg.inv(gmm.precisions_), gmm.covariances_)
@@ -1372,6 +1328,58 @@ def test_gaussian_mixture_precisions_init_diag():
     )
 
 
+def _generate_data(seed, n_samples, n_features, n_components):
+    """Randomly generate samples and responsibilities."""
+    rs = np.random.RandomState(seed)
+    X = rs.random_sample((n_samples, n_features))
+    resp = rs.random_sample((n_samples, n_components))
+    resp /= resp.sum(axis=1)[:, np.newaxis]
+    return X, resp
+
+
+def _calculate_precisions(X, resp, covariance_type):
+    """Calculate precision matrix of X and its Cholesky decomposition
+    for the given covariance type.
+    """
+    reg_covar = 1e-6
+    weights, means, covariances = _estimate_gaussian_parameters(
+        X, resp, reg_covar, covariance_type
+    )
+    precisions_cholesky = _compute_precision_cholesky(covariances, covariance_type)
+
+    _, n_components = resp.shape
+    # Instantiate a `GaussianMixture` model in order to use its
+    # `_set_parameters` method to return the `precisions_` and
+    #  `precisions_cholesky_` from matching the `covariance_type`
+    # provided.
+    gmm = GaussianMixture(n_components=n_components, covariance_type=covariance_type)
+    params = (weights, means, covariances, precisions_cholesky)
+    gmm._set_parameters(params)
+    return gmm.precisions_, gmm.precisions_cholesky_
+
+
+@pytest.mark.parametrize("covariance_type", COVARIANCE_TYPE)
+def test_gaussian_mixture_precisions_init(covariance_type, global_random_seed):
+    """Non-regression test for #26415."""
+
+    X, resp = _generate_data(
+        seed=global_random_seed,
+        n_samples=100,
+        n_features=3,
+        n_components=4,
+    )
+
+    precisions_init, desired_precisions_cholesky = _calculate_precisions(
+        X, resp, covariance_type
+    )
+    gmm = GaussianMixture(
+        covariance_type=covariance_type, precisions_init=precisions_init
+    )
+    gmm._initialize(X, resp)
+    actual_precisions_cholesky = gmm.precisions_cholesky_
+    assert_allclose(actual_precisions_cholesky, desired_precisions_cholesky)
+
+
 def test_gaussian_mixture_single_component_stable():
     """
     Non-regression test for #23032 ensuring 1-component GM works on only a
@@ -1381,3 +1389,34 @@ def test_gaussian_mixture_single_component_stable():
     X = rng.multivariate_normal(np.zeros(2), np.identity(2), size=3)
     gm = GaussianMixture(n_components=1)
     gm.fit(X).sample()
+
+
+def test_gaussian_mixture_all_init_does_not_estimate_gaussian_parameters(
+    monkeypatch,
+    global_random_seed,
+):
+    """When all init parameters are provided, the Gaussian parameters
+    are not estimated.
+
+    Non-regression test for gh-26015.
+    """
+
+    mock = Mock(side_effect=_estimate_gaussian_parameters)
+    monkeypatch.setattr(
+        sklearn.mixture._gaussian_mixture, "_estimate_gaussian_parameters", mock
+    )
+
+    rng = np.random.RandomState(global_random_seed)
+    rand_data = RandomData(rng)
+
+    gm = GaussianMixture(
+        n_components=rand_data.n_components,
+        weights_init=rand_data.weights,
+        means_init=rand_data.means,
+        precisions_init=rand_data.precisions["full"],
+        random_state=rng,
+    )
+    gm.fit(rand_data.X["full"])
+    # The initial gaussian parameters are not estimated. They are estimated for every
+    # m_step.
+    assert mock.call_count == gm.n_iter_
