@@ -8,19 +8,33 @@ from sklearn.linear_model import LogisticRegressionCV
 from sklearn.pipeline import make_pipeline
 from sklearn.base import BaseEstimator, TransformerMixin
 from sklearn.feature_selection import SelectKBest, chi2
-from sklearn import set_config
+from sklearn import config_context
 
 
 # Ignore flake8 (lots of line too long issues)
-# flake8: noqa
+# ruff: noqa
+
 
 # Constructors excerpted to test pprinting
 class LogisticRegression(BaseEstimator):
-    def __init__(self, penalty='l2', dual=False, tol=1e-4, C=1.0,
-                 fit_intercept=True, intercept_scaling=1, class_weight=None,
-                 random_state=None, solver='warn', max_iter=100,
-                 multi_class='warn', verbose=0, warm_start=False, n_jobs=None,
-                 l1_ratio=None):
+    def __init__(
+        self,
+        penalty="l2",
+        dual=False,
+        tol=1e-4,
+        C=1.0,
+        fit_intercept=True,
+        intercept_scaling=1,
+        class_weight=None,
+        random_state=None,
+        solver="warn",
+        max_iter=100,
+        multi_class="warn",
+        verbose=0,
+        warm_start=False,
+        n_jobs=None,
+        l1_ratio=None,
+    ):
         self.penalty = penalty
         self.dual = dual
         self.tol = tol
@@ -52,8 +66,7 @@ class StandardScaler(TransformerMixin, BaseEstimator):
 
 
 class RFE(BaseEstimator):
-    def __init__(self, estimator, n_features_to_select=None, step=1,
-                 verbose=0):
+    def __init__(self, estimator, n_features_to_select=None, step=1, verbose=0):
         self.estimator = estimator
         self.n_features_to_select = n_features_to_select
         self.step = step
@@ -61,10 +74,20 @@ class RFE(BaseEstimator):
 
 
 class GridSearchCV(BaseEstimator):
-    def __init__(self, estimator, param_grid, scoring=None,
-                 n_jobs=None, iid='warn', refit=True, cv='warn', verbose=0,
-                 pre_dispatch='2*n_jobs', error_score='raise-deprecating',
-                 return_train_score=False):
+    def __init__(
+        self,
+        estimator,
+        param_grid,
+        scoring=None,
+        n_jobs=None,
+        iid="warn",
+        refit=True,
+        cv="warn",
+        verbose=0,
+        pre_dispatch="2*n_jobs",
+        error_score="raise-deprecating",
+        return_train_score=False,
+    ):
         self.estimator = estimator
         self.param_grid = param_grid
         self.scoring = scoring
@@ -79,13 +102,26 @@ class GridSearchCV(BaseEstimator):
 
 
 class CountVectorizer(BaseEstimator):
-    def __init__(self, input='content', encoding='utf-8',
-                 decode_error='strict', strip_accents=None,
-                 lowercase=True, preprocessor=None, tokenizer=None,
-                 stop_words=None, token_pattern=r"(?u)\b\w\w+\b",
-                 ngram_range=(1, 1), analyzer='word',
-                 max_df=1.0, min_df=1, max_features=None,
-                 vocabulary=None, binary=False, dtype=np.int64):
+    def __init__(
+        self,
+        input="content",
+        encoding="utf-8",
+        decode_error="strict",
+        strip_accents=None,
+        lowercase=True,
+        preprocessor=None,
+        tokenizer=None,
+        stop_words=None,
+        token_pattern=r"(?u)\b\w\w+\b",
+        ngram_range=(1, 1),
+        analyzer="word",
+        max_df=1.0,
+        min_df=1,
+        max_features=None,
+        vocabulary=None,
+        binary=False,
+        dtype=np.int64,
+    ):
         self.input = input
         self.encoding = encoding
         self.decode_error = decode_error
@@ -112,11 +148,23 @@ class Pipeline(BaseEstimator):
 
 
 class SVC(BaseEstimator):
-    def __init__(self, C=1.0, kernel='rbf', degree=3, gamma='auto_deprecated',
-                 coef0=0.0, shrinking=True, probability=False,
-                 tol=1e-3, cache_size=200, class_weight=None,
-                 verbose=False, max_iter=-1, decision_function_shape='ovr',
-                 random_state=None):
+    def __init__(
+        self,
+        C=1.0,
+        kernel="rbf",
+        degree=3,
+        gamma="auto_deprecated",
+        coef0=0.0,
+        shrinking=True,
+        probability=False,
+        tol=1e-3,
+        cache_size=200,
+        class_weight=None,
+        verbose=False,
+        max_iter=-1,
+        decision_function_shape="ovr",
+        random_state=None,
+    ):
         self.kernel = kernel
         self.degree = degree
         self.gamma = gamma
@@ -134,9 +182,16 @@ class SVC(BaseEstimator):
 
 
 class PCA(BaseEstimator):
-    def __init__(self, n_components=None, copy=True, whiten=False,
-                 svd_solver='auto', tol=0.0, iterated_power='auto',
-                 random_state=None):
+    def __init__(
+        self,
+        n_components=None,
+        copy=True,
+        whiten=False,
+        svd_solver="auto",
+        tol=0.0,
+        iterated_power="auto",
+        random_state=None,
+    ):
         self.n_components = n_components
         self.copy = copy
         self.whiten = whiten
@@ -147,10 +202,20 @@ class PCA(BaseEstimator):
 
 
 class NMF(BaseEstimator):
-    def __init__(self, n_components=None, init=None, solver='cd',
-                 beta_loss='frobenius', tol=1e-4, max_iter=200,
-                 random_state=None, alpha=0., l1_ratio=0., verbose=0,
-                 shuffle=False):
+    def __init__(
+        self,
+        n_components=None,
+        init=None,
+        solver="cd",
+        beta_loss="frobenius",
+        tol=1e-4,
+        max_iter=200,
+        random_state=None,
+        alpha=0.0,
+        l1_ratio=0.0,
+        verbose=0,
+        shuffle=False,
+    ):
         self.n_components = n_components
         self.init = init
         self.solver = solver
@@ -165,8 +230,14 @@ class NMF(BaseEstimator):
 
 
 class SimpleImputer(BaseEstimator):
-    def __init__(self, missing_values=np.nan, strategy="mean",
-                 fill_value=None, verbose=0, copy=True):
+    def __init__(
+        self,
+        missing_values=np.nan,
+        strategy="mean",
+        fill_value=None,
+        verbose=0,
+        copy=True,
+    ):
         self.missing_values = missing_values
         self.strategy = strategy
         self.fill_value = fill_value
@@ -174,7 +245,7 @@ class SimpleImputer(BaseEstimator):
         self.copy = copy
 
 
-def test_basic():
+def test_basic(print_changed_only_false):
     # Basic pprint test
     lr = LogisticRegression()
     expected = """
@@ -189,15 +260,15 @@ LogisticRegression(C=1.0, class_weight=None, dual=False, fit_intercept=True,
 
 
 def test_changed_only():
-    # Make sure the changed_only param is correctly used
-    set_config(print_changed_only=True)
+    # Make sure the changed_only param is correctly used when True (default)
     lr = LogisticRegression(C=99)
     expected = """LogisticRegression(C=99)"""
     assert lr.__repr__() == expected
 
     # Check with a repr that doesn't fit on a single line
-    lr = LogisticRegression(C=99, class_weight=.4, fit_intercept=False,
-                            tol=1234, verbose=True)
+    lr = LogisticRegression(
+        C=99, class_weight=0.4, fit_intercept=False, tol=1234, verbose=True
+    )
     expected = """
 LogisticRegression(C=99, class_weight=0.4, fit_intercept=False, tol=1234,
                    verbose=True)"""
@@ -208,18 +279,16 @@ LogisticRegression(C=99, class_weight=0.4, fit_intercept=False, tol=1234,
     expected = """SimpleImputer(missing_values=0)"""
     assert imputer.__repr__() == expected
 
-    # Defaults to np.NaN, trying with float('NaN')
-    imputer = SimpleImputer(missing_values=float('NaN'))
+    # Defaults to np.nan, trying with float('NaN')
+    imputer = SimpleImputer(missing_values=float("NaN"))
     expected = """SimpleImputer()"""
     assert imputer.__repr__() == expected
 
     # make sure array parameters don't throw error (see #13583)
     repr(LogisticRegressionCV(Cs=np.array([0.1, 1])))
 
-    set_config(print_changed_only=False)
 
-
-def test_pipeline():
+def test_pipeline(print_changed_only_false):
     # Render a pipeline object
     pipeline = make_pipeline(StandardScaler(), LogisticRegression(C=999))
     expected = """
@@ -240,7 +309,7 @@ Pipeline(memory=None,
     assert pipeline.__repr__() == expected
 
 
-def test_deeply_nested():
+def test_deeply_nested(print_changed_only_false):
     # Render a deeply nested estimator
     rfe = RFE(RFE(RFE(RFE(RFE(RFE(RFE(LogisticRegression())))))))
     expected = """
@@ -277,11 +346,12 @@ RFE(estimator=RFE(estimator=RFE(estimator=RFE(estimator=RFE(estimator=RFE(estima
     assert rfe.__repr__() == expected
 
 
-def test_gridsearch():
+def test_gridsearch(print_changed_only_false):
     # render a gridsearch
-    param_grid = [{'kernel': ['rbf'], 'gamma': [1e-3, 1e-4],
-                   'C': [1, 10, 100, 1000]},
-                  {'kernel': ['linear'], 'C': [1, 10, 100, 1000]}]
+    param_grid = [
+        {"kernel": ["rbf"], "gamma": [1e-3, 1e-4], "C": [1, 10, 100, 1000]},
+        {"kernel": ["linear"], "C": [1, 10, 100, 1000]},
+    ]
     gs = GridSearchCV(SVC(), param_grid, cv=5)
 
     expected = """
@@ -302,27 +372,24 @@ GridSearchCV(cv=5, error_score='raise-deprecating',
     assert gs.__repr__() == expected
 
 
-def test_gridsearch_pipeline():
+def test_gridsearch_pipeline(print_changed_only_false):
     # render a pipeline inside a gridsearch
     pp = _EstimatorPrettyPrinter(compact=True, indent=1, indent_at_name=True)
 
-    pipeline = Pipeline([
-        ('reduce_dim', PCA()),
-        ('classify', SVC())
-    ])
+    pipeline = Pipeline([("reduce_dim", PCA()), ("classify", SVC())])
     N_FEATURES_OPTIONS = [2, 4, 8]
     C_OPTIONS = [1, 10, 100, 1000]
     param_grid = [
         {
-            'reduce_dim': [PCA(iterated_power=7), NMF()],
-            'reduce_dim__n_components': N_FEATURES_OPTIONS,
-            'classify__C': C_OPTIONS
+            "reduce_dim": [PCA(iterated_power=7), NMF()],
+            "reduce_dim__n_components": N_FEATURES_OPTIONS,
+            "classify__C": C_OPTIONS,
         },
         {
-            'reduce_dim': [SelectKBest(chi2)],
-            'reduce_dim__k': N_FEATURES_OPTIONS,
-            'classify__C': C_OPTIONS
-        }
+            "reduce_dim": [SelectKBest(chi2)],
+            "reduce_dim__k": N_FEATURES_OPTIONS,
+            "classify__C": C_OPTIONS,
+        },
     ]
     gspipline = GridSearchCV(pipeline, cv=3, n_jobs=1, param_grid=param_grid)
     expected = """
@@ -367,16 +434,17 @@ GridSearchCV(cv=3, error_score='raise-deprecating',
     expected = expected[1:]  # remove first \n
     repr_ = pp.pformat(gspipline)
     # Remove address of '<function chi2 at 0x.....>' for reproducibility
-    repr_ = re.sub('function chi2 at 0x.*>',
-                   'function chi2 at some_address>', repr_)
+    repr_ = re.sub("function chi2 at 0x.*>", "function chi2 at some_address>", repr_)
     assert repr_ == expected
 
-def test_n_max_elements_to_show():
 
+def test_n_max_elements_to_show(print_changed_only_false):
     n_max_elements_to_show = 30
     pp = _EstimatorPrettyPrinter(
-        compact=True, indent=1, indent_at_name=True,
-        n_max_elements_to_show=n_max_elements_to_show
+        compact=True,
+        indent=1,
+        indent_at_name=True,
+        n_max_elements_to_show=n_max_elements_to_show,
     )
 
     # No ellipsis
@@ -397,7 +465,7 @@ CountVectorizer(analyzer='word', binary=False, decode_error='strict',
                             27: 27, 28: 28, 29: 29})"""
 
     expected = expected[1:]  # remove first \n
-    assert  pp.pformat(vectorizer) == expected
+    assert pp.pformat(vectorizer) == expected
 
     # Now with ellipsis
     vocabulary = {i: i for i in range(n_max_elements_to_show + 1)}
@@ -417,10 +485,10 @@ CountVectorizer(analyzer='word', binary=False, decode_error='strict',
                             27: 27, 28: 28, 29: 29, ...})"""
 
     expected = expected[1:]  # remove first \n
-    assert  pp.pformat(vectorizer) == expected
+    assert pp.pformat(vectorizer) == expected
 
     # Also test with lists
-    param_grid = {'C': list(range(n_max_elements_to_show))}
+    param_grid = {"C": list(range(n_max_elements_to_show))}
     gs = GridSearchCV(SVC(), param_grid)
     expected = """
 GridSearchCV(cv='warn', error_score='raise-deprecating',
@@ -437,10 +505,10 @@ GridSearchCV(cv='warn', error_score='raise-deprecating',
              scoring=None, verbose=0)"""
 
     expected = expected[1:]  # remove first \n
-    assert  pp.pformat(gs) == expected
+    assert pp.pformat(gs) == expected
 
     # Now with ellipsis
-    param_grid = {'C': list(range(n_max_elements_to_show + 1))}
+    param_grid = {"C": list(range(n_max_elements_to_show + 1))}
     gs = GridSearchCV(SVC(), param_grid)
     expected = """
 GridSearchCV(cv='warn', error_score='raise-deprecating',
@@ -457,10 +525,10 @@ GridSearchCV(cv='warn', error_score='raise-deprecating',
              scoring=None, verbose=0)"""
 
     expected = expected[1:]  # remove first \n
-    assert  pp.pformat(gs) == expected
+    assert pp.pformat(gs) == expected
 
 
-def test_bruteforce_ellipsis():
+def test_bruteforce_ellipsis(print_changed_only_false):
     # Check that the bruteforce ellipsis (used when the number of non-blank
     # characters exceeds N_CHAR_MAX) renders correctly.
 
@@ -491,10 +559,10 @@ Lo...
 
     # test with N_CHAR_MAX == number of non-blank characters: In this case we
     # don't want ellipsis
-    full_repr = lr.__repr__(N_CHAR_MAX=float('inf'))
-    n_nonblank = len(''.join(full_repr.split()))
+    full_repr = lr.__repr__(N_CHAR_MAX=float("inf"))
+    n_nonblank = len("".join(full_repr.split()))
     assert lr.__repr__(N_CHAR_MAX=n_nonblank) == full_repr
-    assert '...' not in full_repr
+    assert "..." not in full_repr
 
     # test with N_CHAR_MAX == number of non-blank characters - 10: the left and
     # right side of the ellispsis are on different lines. In this case we
@@ -533,9 +601,80 @@ LogisticRegression(C=1.0, class_weight=None, dual=False, fit_intercept=True,
     expected = expected[1:]  # remove first \n
     assert expected == lr.__repr__(N_CHAR_MAX=n_nonblank - 2)
 
+
 def test_builtin_prettyprinter():
     # non regression test than ensures we can still use the builtin
     # PrettyPrinter class for estimators (as done e.g. by joblib).
     # Used to be a bug
 
     PrettyPrinter().pprint(LogisticRegression())
+
+
+def test_kwargs_in_init():
+    # Make sure the changed_only=True mode is OK when an argument is passed as
+    # kwargs.
+    # Non-regression test for
+    # https://github.com/scikit-learn/scikit-learn/issues/17206
+
+    class WithKWargs(BaseEstimator):
+        # Estimator with a kwargs argument. These need to hack around
+        # set_params and get_params. Here we mimic what LightGBM does.
+        def __init__(self, a="willchange", b="unchanged", **kwargs):
+            self.a = a
+            self.b = b
+            self._other_params = {}
+            self.set_params(**kwargs)
+
+        def get_params(self, deep=True):
+            params = super().get_params(deep=deep)
+            params.update(self._other_params)
+            return params
+
+        def set_params(self, **params):
+            for key, value in params.items():
+                setattr(self, key, value)
+                self._other_params[key] = value
+            return self
+
+    est = WithKWargs(a="something", c="abcd", d=None)
+
+    expected = "WithKWargs(a='something', c='abcd', d=None)"
+    assert expected == est.__repr__()
+
+    with config_context(print_changed_only=False):
+        expected = "WithKWargs(a='something', b='unchanged', c='abcd', d=None)"
+        assert expected == est.__repr__()
+
+
+def test_complexity_print_changed_only():
+    # Make sure `__repr__` is called the same amount of times
+    # whether `print_changed_only` is True or False
+    # Non-regression test for
+    # https://github.com/scikit-learn/scikit-learn/issues/18490
+
+    class DummyEstimator(TransformerMixin, BaseEstimator):
+        nb_times_repr_called = 0
+
+        def __init__(self, estimator=None):
+            self.estimator = estimator
+
+        def __repr__(self):
+            DummyEstimator.nb_times_repr_called += 1
+            return super().__repr__()
+
+        def transform(self, X, copy=None):  # pragma: no cover
+            return X
+
+    estimator = DummyEstimator(
+        make_pipeline(DummyEstimator(DummyEstimator()), DummyEstimator(), "passthrough")
+    )
+    with config_context(print_changed_only=False):
+        repr(estimator)
+        nb_repr_print_changed_only_false = DummyEstimator.nb_times_repr_called
+
+    DummyEstimator.nb_times_repr_called = 0
+    with config_context(print_changed_only=True):
+        repr(estimator)
+        nb_repr_print_changed_only_true = DummyEstimator.nb_times_repr_called
+
+    assert nb_repr_print_changed_only_false == nb_repr_print_changed_only_true
